Class: Aws::EntityResolution::Client
- Inherits:
-
Seahorse::Client::Base
- Object
- Seahorse::Client::Base
- Aws::EntityResolution::Client
- Includes:
- ClientStubs
- Defined in:
- lib/aws-sdk-entityresolution/client.rb,
sig/client.rbs
Overview
An API client for EntityResolution. To construct a client, you need to configure a :region and :credentials.
client = Aws::EntityResolution::Client.new(
region: region_name,
credentials: credentials,
# ...
)
For details on configuring region and credentials see the developer guide.
See #initialize for a full list of supported configuration options.
Defined Under Namespace
Modules: _AddPolicyStatementResponseSuccess, _BatchDeleteUniqueIdResponseSuccess, _CreateIdMappingWorkflowResponseSuccess, _CreateIdNamespaceResponseSuccess, _CreateMatchingWorkflowResponseSuccess, _CreateSchemaMappingResponseSuccess, _DeleteIdMappingWorkflowResponseSuccess, _DeleteIdNamespaceResponseSuccess, _DeleteMatchingWorkflowResponseSuccess, _DeletePolicyStatementResponseSuccess, _DeleteSchemaMappingResponseSuccess, _GenerateMatchIdResponseSuccess, _GetIdMappingJobResponseSuccess, _GetIdMappingWorkflowResponseSuccess, _GetIdNamespaceResponseSuccess, _GetMatchIdResponseSuccess, _GetMatchingJobResponseSuccess, _GetMatchingWorkflowResponseSuccess, _GetPolicyResponseSuccess, _GetProviderServiceResponseSuccess, _GetSchemaMappingResponseSuccess, _ListIdMappingJobsResponseSuccess, _ListIdMappingWorkflowsResponseSuccess, _ListIdNamespacesResponseSuccess, _ListMatchingJobsResponseSuccess, _ListMatchingWorkflowsResponseSuccess, _ListProviderServicesResponseSuccess, _ListSchemaMappingsResponseSuccess, _ListTagsForResourceResponseSuccess, _PutPolicyResponseSuccess, _StartIdMappingJobResponseSuccess, _StartMatchingJobResponseSuccess, _TagResourceResponseSuccess, _UntagResourceResponseSuccess, _UpdateIdMappingWorkflowResponseSuccess, _UpdateIdNamespaceResponseSuccess, _UpdateMatchingWorkflowResponseSuccess, _UpdateSchemaMappingResponseSuccess
Constant Summary collapse
- Params =
Class Attribute Summary collapse
- .identifier ⇒ Object readonly private
API Operations collapse
-
#add_policy_statement(params = {}) ⇒ Types::AddPolicyStatementOutput
Adds a policy statement object.
-
#batch_delete_unique_id(params = {}) ⇒ Types::BatchDeleteUniqueIdOutput
Deletes multiple unique IDs in a matching workflow.
-
#create_id_mapping_workflow(params = {}) ⇒ Types::CreateIdMappingWorkflowOutput
Creates an
IdMappingWorkflowobject which stores the configuration of the data processing job to be run. -
#create_id_namespace(params = {}) ⇒ Types::CreateIdNamespaceOutput
Creates an ID namespace object which will help customers provide metadata explaining their dataset and how to use it.
-
#create_matching_workflow(params = {}) ⇒ Types::CreateMatchingWorkflowOutput
Creates a matching workflow that defines the configuration for a data processing job.
-
#create_schema_mapping(params = {}) ⇒ Types::CreateSchemaMappingOutput
Creates a schema mapping, which defines the schema of the input customer records table.
-
#delete_id_mapping_workflow(params = {}) ⇒ Types::DeleteIdMappingWorkflowOutput
Deletes the
IdMappingWorkflowwith a given name. -
#delete_id_namespace(params = {}) ⇒ Types::DeleteIdNamespaceOutput
Deletes the
IdNamespacewith a given name. -
#delete_matching_workflow(params = {}) ⇒ Types::DeleteMatchingWorkflowOutput
Deletes the
MatchingWorkflowwith a given name. -
#delete_policy_statement(params = {}) ⇒ Types::DeletePolicyStatementOutput
Deletes the policy statement.
-
#delete_schema_mapping(params = {}) ⇒ Types::DeleteSchemaMappingOutput
Deletes the
SchemaMappingwith a given name. -
#generate_match_id(params = {}) ⇒ Types::GenerateMatchIdOutput
Generates or retrieves Match IDs for records using a rule-based matching workflow.
-
#get_id_mapping_job(params = {}) ⇒ Types::GetIdMappingJobOutput
Returns the status, metrics, and errors (if there are any) that are associated with a job.
-
#get_id_mapping_workflow(params = {}) ⇒ Types::GetIdMappingWorkflowOutput
Returns the
IdMappingWorkflowwith a given name, if it exists. -
#get_id_namespace(params = {}) ⇒ Types::GetIdNamespaceOutput
Returns the
IdNamespacewith a given name, if it exists. -
#get_match_id(params = {}) ⇒ Types::GetMatchIdOutput
Returns the corresponding Match ID of a customer record if the record has been processed in a rule-based matching workflow.
-
#get_matching_job(params = {}) ⇒ Types::GetMatchingJobOutput
Returns the status, metrics, and errors (if there are any) that are associated with a job.
-
#get_matching_workflow(params = {}) ⇒ Types::GetMatchingWorkflowOutput
Returns the
MatchingWorkflowwith a given name, if it exists. -
#get_policy(params = {}) ⇒ Types::GetPolicyOutput
Returns the resource-based policy.
-
#get_provider_service(params = {}) ⇒ Types::GetProviderServiceOutput
Returns the
ProviderServiceof a given name. -
#get_schema_mapping(params = {}) ⇒ Types::GetSchemaMappingOutput
Returns the SchemaMapping of a given name.
-
#list_id_mapping_jobs(params = {}) ⇒ Types::ListIdMappingJobsOutput
Lists all ID mapping jobs for a given workflow.
-
#list_id_mapping_workflows(params = {}) ⇒ Types::ListIdMappingWorkflowsOutput
Returns a list of all the
IdMappingWorkflowsthat have been created for an Amazon Web Services account. -
#list_id_namespaces(params = {}) ⇒ Types::ListIdNamespacesOutput
Returns a list of all ID namespaces.
-
#list_matching_jobs(params = {}) ⇒ Types::ListMatchingJobsOutput
Lists all jobs for a given workflow.
-
#list_matching_workflows(params = {}) ⇒ Types::ListMatchingWorkflowsOutput
Returns a list of all the
MatchingWorkflowsthat have been created for an Amazon Web Services account. -
#list_provider_services(params = {}) ⇒ Types::ListProviderServicesOutput
Returns a list of all the
ProviderServicesthat are available in this Amazon Web Services Region. -
#list_schema_mappings(params = {}) ⇒ Types::ListSchemaMappingsOutput
Returns a list of all the
SchemaMappingsthat have been created for an Amazon Web Services account. -
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceOutput
Displays the tags associated with an Entity Resolution resource.
-
#put_policy(params = {}) ⇒ Types::PutPolicyOutput
Updates the resource-based policy.
-
#start_id_mapping_job(params = {}) ⇒ Types::StartIdMappingJobOutput
Starts the
IdMappingJobof a workflow. -
#start_matching_job(params = {}) ⇒ Types::StartMatchingJobOutput
Starts the
MatchingJobof a workflow. -
#tag_resource(params = {}) ⇒ Struct
Assigns one or more tags (key-value pairs) to the specified Entity Resolution resource.
-
#untag_resource(params = {}) ⇒ Struct
Removes one or more tags from the specified Entity Resolution resource.
-
#update_id_mapping_workflow(params = {}) ⇒ Types::UpdateIdMappingWorkflowOutput
Updates an existing
IdMappingWorkflow. -
#update_id_namespace(params = {}) ⇒ Types::UpdateIdNamespaceOutput
Updates an existing ID namespace.
-
#update_matching_workflow(params = {}) ⇒ Types::UpdateMatchingWorkflowOutput
Updates an existing matching workflow.
-
#update_schema_mapping(params = {}) ⇒ Types::UpdateSchemaMappingOutput
Updates a schema mapping.
Class Method Summary collapse
- .errors_module ⇒ Object private
- .new ⇒ Object
Instance Method Summary collapse
- #build_request(operation_name, params = {}) ⇒ Object private
-
#initialize(options) ⇒ Client
constructor
A new instance of Client.
- #waiter_names ⇒ Object deprecated private Deprecated.
Constructor Details
#initialize(options) ⇒ Client
Returns a new instance of Client.
471 472 473 |
# File 'lib/aws-sdk-entityresolution/client.rb', line 471 def initialize(*args) super end |
Class Attribute Details
.identifier ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
2854 2855 2856 |
# File 'lib/aws-sdk-entityresolution/client.rb', line 2854 def identifier @identifier end |
Class Method Details
.errors_module ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
2857 2858 2859 |
# File 'lib/aws-sdk-entityresolution/client.rb', line 2857 def errors_module Errors end |
.new ⇒ Object
14 |
# File 'sig/client.rbs', line 14
def self.new: (
|
Instance Method Details
#add_policy_statement(params = {}) ⇒ Types::AddPolicyStatementOutput
Adds a policy statement object. To retrieve a list of existing policy
statements, use the GetPolicy API.
88 |
# File 'sig/client.rbs', line 88
def add_policy_statement: (
|
#batch_delete_unique_id(params = {}) ⇒ Types::BatchDeleteUniqueIdOutput
Deletes multiple unique IDs in a matching workflow.
106 |
# File 'sig/client.rbs', line 106
def batch_delete_unique_id: (
|
#build_request(operation_name, params = {}) ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
2827 2828 2829 2830 2831 2832 2833 2834 2835 2836 2837 2838 2839 2840 2841 2842 2843 |
# File 'lib/aws-sdk-entityresolution/client.rb', line 2827 def build_request(operation_name, params = {}) handlers = @handlers.for(operation_name) tracer = config.telemetry_provider.tracer_provider.tracer( Aws::Telemetry.module_to_tracer_name('Aws::EntityResolution') ) context = Seahorse::Client::RequestContext.new( operation_name: operation_name, operation: config.api.operation(operation_name), client: self, params: params, config: config, tracer: tracer ) context[:gem_name] = 'aws-sdk-entityresolution' context[:gem_version] = '1.53.0' Seahorse::Client::Request.new(handlers, context) end |
#create_id_mapping_workflow(params = {}) ⇒ Types::CreateIdMappingWorkflowOutput
Creates an IdMappingWorkflow object which stores the configuration
of the data processing job to be run. Each IdMappingWorkflow must
have a unique workflow name. To modify an existing workflow, use the
UpdateIdMappingWorkflow API.
Incremental processing is not supported for ID mapping workflows.
125 |
# File 'sig/client.rbs', line 125
def create_id_mapping_workflow: (
|
#create_id_namespace(params = {}) ⇒ Types::CreateIdNamespaceOutput
Creates an ID namespace object which will help customers provide metadata explaining their dataset and how to use it. Each ID namespace must have a unique name. To modify an existing ID namespace, use the UpdateIdNamespace API.
164 |
# File 'sig/client.rbs', line 164
def create_id_namespace: (
|
#create_matching_workflow(params = {}) ⇒ Types::CreateMatchingWorkflowOutput
Creates a matching workflow that defines the configuration for a data
processing job. The workflow name must be unique. To modify an
existing workflow, use UpdateMatchingWorkflow.
For workflows where resolutionType is PROVIDER, incremental
processing is not supported.
194 |
# File 'sig/client.rbs', line 194
def create_matching_workflow: (
|
#create_schema_mapping(params = {}) ⇒ Types::CreateSchemaMappingOutput
Creates a schema mapping, which defines the schema of the input
customer records table. The SchemaMapping also provides Entity
Resolution with some metadata about the table, such as the attribute
types of the columns and which columns to match on.
224 |
# File 'sig/client.rbs', line 224
def create_schema_mapping: (
|
#delete_id_mapping_workflow(params = {}) ⇒ Types::DeleteIdMappingWorkflowOutput
Deletes the IdMappingWorkflow with a given name. This operation
returns a ResourceNotFoundException if a workflow with the given
name does not exist.
239 |
# File 'sig/client.rbs', line 239
def delete_id_mapping_workflow: (
|
#delete_id_namespace(params = {}) ⇒ Types::DeleteIdNamespaceOutput
Deletes the IdNamespace with a given name. This operation returns a
ResourceNotFoundException if an ID namespace with the given name
does not exist.
249 |
# File 'sig/client.rbs', line 249
def delete_id_namespace: (
|
#delete_matching_workflow(params = {}) ⇒ Types::DeleteMatchingWorkflowOutput
Deletes the MatchingWorkflow with a given name. This operation
returns a ResourceNotFoundException if a workflow with the given
name does not exist.
259 |
# File 'sig/client.rbs', line 259
def delete_matching_workflow: (
|
#delete_policy_statement(params = {}) ⇒ Types::DeletePolicyStatementOutput
Deletes the policy statement.
271 |
# File 'sig/client.rbs', line 271
def delete_policy_statement: (
|
#delete_schema_mapping(params = {}) ⇒ Types::DeleteSchemaMappingOutput
Deletes the SchemaMapping with a given name. This operation returns
a ResourceNotFoundException if a schema with the given name does not
exist. This operation will fail if there is a MatchingWorkflow
object that references the SchemaMapping in the workflow's
InputSourceConfig.
282 |
# File 'sig/client.rbs', line 282
def delete_schema_mapping: (
|
#generate_match_id(params = {}) ⇒ Types::GenerateMatchIdOutput
Generates or retrieves Match IDs for records using a rule-based matching workflow. When you call this operation, it processes your records against the workflow's matching rules to identify potential matches. For existing records, it retrieves their Match IDs and associated rules. For records without matches, it generates new Match IDs. The operation saves results to Amazon S3.
The processing type (processingType) you choose affects both the
accuracy and response time of the operation. Additional charges apply
for each API call, whether made through the Entity Resolution console
or directly via the API. The rule-based matching workflow must exist
and be active before calling this operation.
293 |
# File 'sig/client.rbs', line 293
def generate_match_id: (
|
#get_id_mapping_job(params = {}) ⇒ Types::GetIdMappingJobOutput
Returns the status, metrics, and errors (if there are any) that are associated with a job.
318 |
# File 'sig/client.rbs', line 318
def get_id_mapping_job: (
|
#get_id_mapping_workflow(params = {}) ⇒ Types::GetIdMappingWorkflowOutput
Returns the IdMappingWorkflow with a given name, if it exists.
339 |
# File 'sig/client.rbs', line 339
def get_id_mapping_workflow: (
|
#get_id_namespace(params = {}) ⇒ Types::GetIdNamespaceOutput
Returns the IdNamespace with a given name, if it exists.
358 |
# File 'sig/client.rbs', line 358
def get_id_namespace: (
|
#get_match_id(params = {}) ⇒ Types::GetMatchIdOutput
Returns the corresponding Match ID of a customer record if the record has been processed in a rule-based matching workflow.
You can call this API as a dry run of an incremental load on the rule-based matching workflow.
369 |
# File 'sig/client.rbs', line 369
def get_match_id: (
|
#get_matching_job(params = {}) ⇒ Types::GetMatchingJobOutput
Returns the status, metrics, and errors (if there are any) that are associated with a job.
387 |
# File 'sig/client.rbs', line 387
def get_matching_job: (
|
#get_matching_workflow(params = {}) ⇒ Types::GetMatchingWorkflowOutput
Returns the MatchingWorkflow with a given name, if it exists.
408 |
# File 'sig/client.rbs', line 408
def get_matching_workflow: (
|
#get_policy(params = {}) ⇒ Types::GetPolicyOutput
Returns the resource-based policy.
420 |
# File 'sig/client.rbs', line 420
def get_policy: (
|
#get_provider_service(params = {}) ⇒ Types::GetProviderServiceOutput
Returns the ProviderService of a given name.
442 |
# File 'sig/client.rbs', line 442
def get_provider_service: (
|
#get_schema_mapping(params = {}) ⇒ Types::GetSchemaMappingOutput
Returns the SchemaMapping of a given name.
460 |
# File 'sig/client.rbs', line 460
def get_schema_mapping: (
|
#list_id_mapping_jobs(params = {}) ⇒ Types::ListIdMappingJobsOutput
Lists all ID mapping jobs for a given workflow.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
471 |
# File 'sig/client.rbs', line 471
def list_id_mapping_jobs: (
|
#list_id_mapping_workflows(params = {}) ⇒ Types::ListIdMappingWorkflowsOutput
Returns a list of all the IdMappingWorkflows that have been created
for an Amazon Web Services account.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
484 |
# File 'sig/client.rbs', line 484
def list_id_mapping_workflows: (
|
#list_id_namespaces(params = {}) ⇒ Types::ListIdNamespacesOutput
Returns a list of all ID namespaces.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
496 |
# File 'sig/client.rbs', line 496
def list_id_namespaces: (
|
#list_matching_jobs(params = {}) ⇒ Types::ListMatchingJobsOutput
Lists all jobs for a given workflow.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
508 |
# File 'sig/client.rbs', line 508
def list_matching_jobs: (
|
#list_matching_workflows(params = {}) ⇒ Types::ListMatchingWorkflowsOutput
Returns a list of all the MatchingWorkflows that have been created
for an Amazon Web Services account.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
521 |
# File 'sig/client.rbs', line 521
def list_matching_workflows: (
|
#list_provider_services(params = {}) ⇒ Types::ListProviderServicesOutput
Returns a list of all the ProviderServices that are available in
this Amazon Web Services Region.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
533 |
# File 'sig/client.rbs', line 533
def list_provider_services: (
|
#list_schema_mappings(params = {}) ⇒ Types::ListSchemaMappingsOutput
Returns a list of all the SchemaMappings that have been created for
an Amazon Web Services account.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
546 |
# File 'sig/client.rbs', line 546
def list_schema_mappings: (
|
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceOutput
Displays the tags associated with an Entity Resolution resource. In
Entity Resolution, SchemaMapping, and MatchingWorkflow can be
tagged.
557 |
# File 'sig/client.rbs', line 557
def list_tags_for_resource: (
|
#put_policy(params = {}) ⇒ Types::PutPolicyOutput
Updates the resource-based policy.
569 |
# File 'sig/client.rbs', line 569
def put_policy: (
|
#start_id_mapping_job(params = {}) ⇒ Types::StartIdMappingJobOutput
Starts the IdMappingJob of a workflow. The workflow must have
previously been created using the CreateIdMappingWorkflow endpoint.
583 |
# File 'sig/client.rbs', line 583
def start_id_mapping_job: (
|
#start_matching_job(params = {}) ⇒ Types::StartMatchingJobOutput
Starts the MatchingJob of a workflow. The workflow must have
previously been created using the CreateMatchingWorkflow endpoint.
601 |
# File 'sig/client.rbs', line 601
def start_matching_job: (
|
#tag_resource(params = {}) ⇒ Struct
Assigns one or more tags (key-value pairs) to the specified Entity
Resolution resource. Tags can help you organize and categorize your
resources. You can also use them to scope user permissions by granting
a user permission to access or change only resources with certain tag
values. In Entity Resolution, SchemaMapping and MatchingWorkflow
can be tagged. Tags don't have any semantic meaning to Amazon Web
Services and are interpreted strictly as strings of characters. You
can use the TagResource action with a resource that already has
tags. If you specify a new tag key, this tag is appended to the list
of tags associated with the resource. If you specify a tag key that is
already associated with the resource, the new tag value that you
specify replaces the previous value for that tag.
610 |
# File 'sig/client.rbs', line 610
def tag_resource: (
|
#untag_resource(params = {}) ⇒ Struct
Removes one or more tags from the specified Entity Resolution
resource. In Entity Resolution, SchemaMapping, and
MatchingWorkflow can be tagged.
620 |
# File 'sig/client.rbs', line 620
def untag_resource: (
|
#update_id_mapping_workflow(params = {}) ⇒ Types::UpdateIdMappingWorkflowOutput
Updates an existing IdMappingWorkflow. This method is identical to
CreateIdMappingWorkflow, except it uses an HTTP PUT request instead
of a POST request, and the IdMappingWorkflow must already exist
for the method to succeed.
Incremental processing is not supported for ID mapping workflows.
638 |
# File 'sig/client.rbs', line 638
def update_id_mapping_workflow: (
|
#update_id_namespace(params = {}) ⇒ Types::UpdateIdNamespaceOutput
Updates an existing ID namespace.
675 |
# File 'sig/client.rbs', line 675
def update_id_namespace: (
|
#update_matching_workflow(params = {}) ⇒ Types::UpdateMatchingWorkflowOutput
Updates an existing matching workflow. The workflow must already exist for this operation to succeed.
For workflows where resolutionType is PROVIDER, incremental
processing is not supported.
702 |
# File 'sig/client.rbs', line 702
def update_matching_workflow: (
|
#update_schema_mapping(params = {}) ⇒ Types::UpdateSchemaMappingOutput
Updates a schema mapping.
731 |
# File 'sig/client.rbs', line 731
def update_schema_mapping: (
|
#waiter_names ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
2847 2848 2849 |
# File 'lib/aws-sdk-entityresolution/client.rb', line 2847 def waiter_names [] end |