Class: Aws::EntityResolution::Types::CreateIdMappingWorkflowInput
- Inherits:
-
Struct
- Object
- Struct
- Aws::EntityResolution::Types::CreateIdMappingWorkflowInput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-entityresolution/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#description ⇒ String
A description of the workflow.
-
#id_mapping_techniques ⇒ Types::IdMappingTechniques
An object which defines the ID mapping technique and any additional configurations.
-
#input_source_config ⇒ Array<Types::IdMappingWorkflowInputSource>
A list of
InputSourceobjects, which have the fieldsInputSourceARNandSchemaName. -
#output_source_config ⇒ Array<Types::IdMappingWorkflowOutputSource>
A list of
IdMappingWorkflowOutputSourceobjects, each of which contains fieldsoutputS3PathandKMSArn. -
#role_arn ⇒ String
The Amazon Resource Name (ARN) of the IAM role.
-
#tags ⇒ Hash<String,String>
The tags used to organize, track, or control access for this resource.
-
#workflow_name ⇒ String
The name of the workflow.
Instance Attribute Details
#description ⇒ String
A description of the workflow.
199 200 201 202 203 204 205 206 207 208 209 |
# File 'lib/aws-sdk-entityresolution/types.rb', line 199 class CreateIdMappingWorkflowInput < Struct.new( :workflow_name, :description, :input_source_config, :output_source_config, :id_mapping_techniques, :role_arn, :tags) SENSITIVE = [] include Aws::Structure end |
#id_mapping_techniques ⇒ Types::IdMappingTechniques
An object which defines the ID mapping technique and any additional configurations.
199 200 201 202 203 204 205 206 207 208 209 |
# File 'lib/aws-sdk-entityresolution/types.rb', line 199 class CreateIdMappingWorkflowInput < Struct.new( :workflow_name, :description, :input_source_config, :output_source_config, :id_mapping_techniques, :role_arn, :tags) SENSITIVE = [] include Aws::Structure end |
#input_source_config ⇒ Array<Types::IdMappingWorkflowInputSource>
A list of InputSource objects, which have the fields InputSourceARN and SchemaName.
199 200 201 202 203 204 205 206 207 208 209 |
# File 'lib/aws-sdk-entityresolution/types.rb', line 199 class CreateIdMappingWorkflowInput < Struct.new( :workflow_name, :description, :input_source_config, :output_source_config, :id_mapping_techniques, :role_arn, :tags) SENSITIVE = [] include Aws::Structure end |
#output_source_config ⇒ Array<Types::IdMappingWorkflowOutputSource>
A list of IdMappingWorkflowOutputSource objects, each of which contains fields outputS3Path and KMSArn.
199 200 201 202 203 204 205 206 207 208 209 |
# File 'lib/aws-sdk-entityresolution/types.rb', line 199 class CreateIdMappingWorkflowInput < Struct.new( :workflow_name, :description, :input_source_config, :output_source_config, :id_mapping_techniques, :role_arn, :tags) SENSITIVE = [] include Aws::Structure end |
#role_arn ⇒ String
The Amazon Resource Name (ARN) of the IAM role. Entity Resolution assumes this role to create resources on your behalf as part of workflow execution.
199 200 201 202 203 204 205 206 207 208 209 |
# File 'lib/aws-sdk-entityresolution/types.rb', line 199 class CreateIdMappingWorkflowInput < Struct.new( :workflow_name, :description, :input_source_config, :output_source_config, :id_mapping_techniques, :role_arn, :tags) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Hash<String,String>
The tags used to organize, track, or control access for this resource.
199 200 201 202 203 204 205 206 207 208 209 |
# File 'lib/aws-sdk-entityresolution/types.rb', line 199 class CreateIdMappingWorkflowInput < Struct.new( :workflow_name, :description, :input_source_config, :output_source_config, :id_mapping_techniques, :role_arn, :tags) SENSITIVE = [] include Aws::Structure end |
#workflow_name ⇒ String
The name of the workflow. There can’t be multiple IdMappingWorkflows with the same name.
199 200 201 202 203 204 205 206 207 208 209 |
# File 'lib/aws-sdk-entityresolution/types.rb', line 199 class CreateIdMappingWorkflowInput < Struct.new( :workflow_name, :description, :input_source_config, :output_source_config, :id_mapping_techniques, :role_arn, :tags) SENSITIVE = [] include Aws::Structure end |