Class: Aws::EntityResolution::Types::CreateIdNamespaceInput

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-entityresolution/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#descriptionString

The description of the ID namespace.

Returns:

  • (String)


311
312
313
314
315
316
317
318
319
320
321
# File 'lib/aws-sdk-entityresolution/types.rb', line 311

class CreateIdNamespaceInput < Struct.new(
  :id_namespace_name,
  :description,
  :input_source_config,
  :id_mapping_workflow_properties,
  :type,
  :role_arn,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#id_mapping_workflow_propertiesArray<Types::IdNamespaceIdMappingWorkflowProperties>

Determines the properties of ‘IdMappingWorflow` where this `IdNamespace` can be used as a `Source` or a `Target`.



311
312
313
314
315
316
317
318
319
320
321
# File 'lib/aws-sdk-entityresolution/types.rb', line 311

class CreateIdNamespaceInput < Struct.new(
  :id_namespace_name,
  :description,
  :input_source_config,
  :id_mapping_workflow_properties,
  :type,
  :role_arn,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#id_namespace_nameString

The name of the ID namespace.

Returns:

  • (String)


311
312
313
314
315
316
317
318
319
320
321
# File 'lib/aws-sdk-entityresolution/types.rb', line 311

class CreateIdNamespaceInput < Struct.new(
  :id_namespace_name,
  :description,
  :input_source_config,
  :id_mapping_workflow_properties,
  :type,
  :role_arn,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#input_source_configArray<Types::IdNamespaceInputSource>

A list of ‘InputSource` objects, which have the fields `InputSourceARN` and `SchemaName`.

Returns:



311
312
313
314
315
316
317
318
319
320
321
# File 'lib/aws-sdk-entityresolution/types.rb', line 311

class CreateIdNamespaceInput < Struct.new(
  :id_namespace_name,
  :description,
  :input_source_config,
  :id_mapping_workflow_properties,
  :type,
  :role_arn,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#role_arnString

The Amazon Resource Name (ARN) of the IAM role. Entity Resolution assumes this role to access the resources defined in this ‘IdNamespace` on your behalf as part of the workflow run.

Returns:

  • (String)


311
312
313
314
315
316
317
318
319
320
321
# File 'lib/aws-sdk-entityresolution/types.rb', line 311

class CreateIdNamespaceInput < Struct.new(
  :id_namespace_name,
  :description,
  :input_source_config,
  :id_mapping_workflow_properties,
  :type,
  :role_arn,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#tagsHash<String,String>

The tags used to organize, track, or control access for this resource.

Returns:

  • (Hash<String,String>)


311
312
313
314
315
316
317
318
319
320
321
# File 'lib/aws-sdk-entityresolution/types.rb', line 311

class CreateIdNamespaceInput < Struct.new(
  :id_namespace_name,
  :description,
  :input_source_config,
  :id_mapping_workflow_properties,
  :type,
  :role_arn,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#typeString

The type of ID namespace. There are two types: ‘SOURCE` and `TARGET`.

The ‘SOURCE` contains configurations for `sourceId` data that will be processed in an ID mapping workflow.

The ‘TARGET` contains a configuration of `targetId` to which all `sourceIds` will resolve to.

Returns:

  • (String)


311
312
313
314
315
316
317
318
319
320
321
# File 'lib/aws-sdk-entityresolution/types.rb', line 311

class CreateIdNamespaceInput < Struct.new(
  :id_namespace_name,
  :description,
  :input_source_config,
  :id_mapping_workflow_properties,
  :type,
  :role_arn,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end