Class: Aws::EntityResolution::Types::CreateMatchingWorkflowInput

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-entityresolution/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#descriptionString

A description of the workflow.

Returns:

  • (String)


438
439
440
441
442
443
444
445
446
447
448
449
# File 'lib/aws-sdk-entityresolution/types.rb', line 438

class CreateMatchingWorkflowInput < Struct.new(
  :workflow_name,
  :description,
  :input_source_config,
  :output_source_config,
  :resolution_techniques,
  :incremental_run_config,
  :role_arn,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#incremental_run_configTypes::IncrementalRunConfig

Optional. An object that defines the incremental run type. This object contains only the incrementalRunType field, which appears as "Automatic" in the console.

For workflows where resolutionType is PROVIDER, incremental processing is not supported.



438
439
440
441
442
443
444
445
446
447
448
449
# File 'lib/aws-sdk-entityresolution/types.rb', line 438

class CreateMatchingWorkflowInput < Struct.new(
  :workflow_name,
  :description,
  :input_source_config,
  :output_source_config,
  :resolution_techniques,
  :incremental_run_config,
  :role_arn,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#input_source_configArray<Types::InputSource>

A list of InputSource objects, which have the fields InputSourceARN and SchemaName.

Returns:



438
439
440
441
442
443
444
445
446
447
448
449
# File 'lib/aws-sdk-entityresolution/types.rb', line 438

class CreateMatchingWorkflowInput < Struct.new(
  :workflow_name,
  :description,
  :input_source_config,
  :output_source_config,
  :resolution_techniques,
  :incremental_run_config,
  :role_arn,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#output_source_configArray<Types::OutputSource>

A list of OutputSource objects, each of which contains fields outputS3Path, applyNormalization, KMSArn, and output.

Returns:



438
439
440
441
442
443
444
445
446
447
448
449
# File 'lib/aws-sdk-entityresolution/types.rb', line 438

class CreateMatchingWorkflowInput < Struct.new(
  :workflow_name,
  :description,
  :input_source_config,
  :output_source_config,
  :resolution_techniques,
  :incremental_run_config,
  :role_arn,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#resolution_techniquesTypes::ResolutionTechniques

An object which defines the resolutionType and the ruleBasedProperties.



438
439
440
441
442
443
444
445
446
447
448
449
# File 'lib/aws-sdk-entityresolution/types.rb', line 438

class CreateMatchingWorkflowInput < Struct.new(
  :workflow_name,
  :description,
  :input_source_config,
  :output_source_config,
  :resolution_techniques,
  :incremental_run_config,
  :role_arn,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#role_arnString

The Amazon Resource Name (ARN) of the IAM role. Entity Resolution assumes this role to create resources on your behalf as part of workflow execution.

Returns:

  • (String)


438
439
440
441
442
443
444
445
446
447
448
449
# File 'lib/aws-sdk-entityresolution/types.rb', line 438

class CreateMatchingWorkflowInput < Struct.new(
  :workflow_name,
  :description,
  :input_source_config,
  :output_source_config,
  :resolution_techniques,
  :incremental_run_config,
  :role_arn,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#tagsHash<String,String>

The tags used to organize, track, or control access for this resource.

Returns:

  • (Hash<String,String>)


438
439
440
441
442
443
444
445
446
447
448
449
# File 'lib/aws-sdk-entityresolution/types.rb', line 438

class CreateMatchingWorkflowInput < Struct.new(
  :workflow_name,
  :description,
  :input_source_config,
  :output_source_config,
  :resolution_techniques,
  :incremental_run_config,
  :role_arn,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#workflow_nameString

The name of the workflow. There can't be multiple MatchingWorkflows with the same name.

Returns:

  • (String)


438
439
440
441
442
443
444
445
446
447
448
449
# File 'lib/aws-sdk-entityresolution/types.rb', line 438

class CreateMatchingWorkflowInput < Struct.new(
  :workflow_name,
  :description,
  :input_source_config,
  :output_source_config,
  :resolution_techniques,
  :incremental_run_config,
  :role_arn,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end