Class: Aws::EntityResolution::Types::CreateMatchingWorkflowOutput
- Inherits:
-
Struct
- Object
- Struct
- Aws::EntityResolution::Types::CreateMatchingWorkflowOutput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-entityresolution/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#description ⇒ String
A description of the workflow.
-
#incremental_run_config ⇒ Types::IncrementalRunConfig
An object which defines an incremental run type and has only ‘incrementalRunType` as a field.
-
#input_source_config ⇒ Array<Types::InputSource>
A list of ‘InputSource` objects, which have the fields `InputSourceARN` and `SchemaName`.
-
#output_source_config ⇒ Array<Types::OutputSource>
A list of ‘OutputSource` objects, each of which contains fields `outputS3Path`, `applyNormalization`, `KMSArn`, and `output`.
-
#resolution_techniques ⇒ Types::ResolutionTechniques
An object which defines the ‘resolutionType` and the `ruleBasedProperties`.
-
#role_arn ⇒ String
The Amazon Resource Name (ARN) of the IAM role.
-
#workflow_arn ⇒ String
The ARN (Amazon Resource Name) that Entity Resolution generated for the ‘MatchingWorkflow`.
-
#workflow_name ⇒ String
The name of the workflow.
Instance Attribute Details
#description ⇒ String
A description of the workflow.
492 493 494 495 496 497 498 499 500 501 502 503 |
# File 'lib/aws-sdk-entityresolution/types.rb', line 492 class CreateMatchingWorkflowOutput < Struct.new( :workflow_name, :workflow_arn, :description, :input_source_config, :output_source_config, :resolution_techniques, :incremental_run_config, :role_arn) SENSITIVE = [] include Aws::Structure end |
#incremental_run_config ⇒ Types::IncrementalRunConfig
An object which defines an incremental run type and has only ‘incrementalRunType` as a field.
492 493 494 495 496 497 498 499 500 501 502 503 |
# File 'lib/aws-sdk-entityresolution/types.rb', line 492 class CreateMatchingWorkflowOutput < Struct.new( :workflow_name, :workflow_arn, :description, :input_source_config, :output_source_config, :resolution_techniques, :incremental_run_config, :role_arn) SENSITIVE = [] include Aws::Structure end |
#input_source_config ⇒ Array<Types::InputSource>
A list of ‘InputSource` objects, which have the fields `InputSourceARN` and `SchemaName`.
492 493 494 495 496 497 498 499 500 501 502 503 |
# File 'lib/aws-sdk-entityresolution/types.rb', line 492 class CreateMatchingWorkflowOutput < Struct.new( :workflow_name, :workflow_arn, :description, :input_source_config, :output_source_config, :resolution_techniques, :incremental_run_config, :role_arn) SENSITIVE = [] include Aws::Structure end |
#output_source_config ⇒ Array<Types::OutputSource>
A list of ‘OutputSource` objects, each of which contains fields `outputS3Path`, `applyNormalization`, `KMSArn`, and `output`.
492 493 494 495 496 497 498 499 500 501 502 503 |
# File 'lib/aws-sdk-entityresolution/types.rb', line 492 class CreateMatchingWorkflowOutput < Struct.new( :workflow_name, :workflow_arn, :description, :input_source_config, :output_source_config, :resolution_techniques, :incremental_run_config, :role_arn) SENSITIVE = [] include Aws::Structure end |
#resolution_techniques ⇒ Types::ResolutionTechniques
An object which defines the ‘resolutionType` and the `ruleBasedProperties`.
492 493 494 495 496 497 498 499 500 501 502 503 |
# File 'lib/aws-sdk-entityresolution/types.rb', line 492 class CreateMatchingWorkflowOutput < Struct.new( :workflow_name, :workflow_arn, :description, :input_source_config, :output_source_config, :resolution_techniques, :incremental_run_config, :role_arn) SENSITIVE = [] include Aws::Structure end |
#role_arn ⇒ String
The Amazon Resource Name (ARN) of the IAM role. Entity Resolution assumes this role to create resources on your behalf as part of workflow execution.
492 493 494 495 496 497 498 499 500 501 502 503 |
# File 'lib/aws-sdk-entityresolution/types.rb', line 492 class CreateMatchingWorkflowOutput < Struct.new( :workflow_name, :workflow_arn, :description, :input_source_config, :output_source_config, :resolution_techniques, :incremental_run_config, :role_arn) SENSITIVE = [] include Aws::Structure end |
#workflow_arn ⇒ String
The ARN (Amazon Resource Name) that Entity Resolution generated for the ‘MatchingWorkflow`.
492 493 494 495 496 497 498 499 500 501 502 503 |
# File 'lib/aws-sdk-entityresolution/types.rb', line 492 class CreateMatchingWorkflowOutput < Struct.new( :workflow_name, :workflow_arn, :description, :input_source_config, :output_source_config, :resolution_techniques, :incremental_run_config, :role_arn) SENSITIVE = [] include Aws::Structure end |
#workflow_name ⇒ String
The name of the workflow.
492 493 494 495 496 497 498 499 500 501 502 503 |
# File 'lib/aws-sdk-entityresolution/types.rb', line 492 class CreateMatchingWorkflowOutput < Struct.new( :workflow_name, :workflow_arn, :description, :input_source_config, :output_source_config, :resolution_techniques, :incremental_run_config, :role_arn) SENSITIVE = [] include Aws::Structure end |