Class: Aws::EntityResolution::Types::GetIdMappingWorkflowOutput
- Inherits:
-
Struct
- Object
- Struct
- Aws::EntityResolution::Types::GetIdMappingWorkflowOutput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-entityresolution/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#created_at ⇒ Time
The timestamp of when the workflow was created.
-
#description ⇒ String
A description of the workflow.
-
#id_mapping_techniques ⇒ Types::IdMappingTechniques
An object which defines the ID mapping technique and any additional configurations.
-
#incremental_run_config ⇒ Types::IdMappingIncrementalRunConfig
The incremental run configuration for the ID mapping workflow.
-
#input_source_config ⇒ Array<Types::IdMappingWorkflowInputSource>
A list of ‘InputSource` objects, which have the fields `InputSourceARN` and `SchemaName`.
-
#output_source_config ⇒ Array<Types::IdMappingWorkflowOutputSource>
A list of ‘OutputSource` objects, each of which contains fields `outputS3Path` and `KMSArn`.
-
#role_arn ⇒ String
The Amazon Resource Name (ARN) of the IAM role.
-
#tags ⇒ Hash<String,String>
The tags used to organize, track, or control access for this resource.
-
#updated_at ⇒ Time
The timestamp of when the workflow was last updated.
-
#workflow_arn ⇒ String
The ARN (Amazon Resource Name) that Entity Resolution generated for the ‘IdMappingWorkflow` .
-
#workflow_name ⇒ String
The name of the workflow.
Instance Attribute Details
#created_at ⇒ Time
The timestamp of when the workflow was created.
1029 1030 1031 1032 1033 1034 1035 1036 1037 1038 1039 1040 1041 1042 1043 |
# File 'lib/aws-sdk-entityresolution/types.rb', line 1029 class GetIdMappingWorkflowOutput < Struct.new( :workflow_name, :workflow_arn, :description, :input_source_config, :output_source_config, :id_mapping_techniques, :created_at, :updated_at, :incremental_run_config, :role_arn, :tags) SENSITIVE = [] include Aws::Structure end |
#description ⇒ String
A description of the workflow.
1029 1030 1031 1032 1033 1034 1035 1036 1037 1038 1039 1040 1041 1042 1043 |
# File 'lib/aws-sdk-entityresolution/types.rb', line 1029 class GetIdMappingWorkflowOutput < Struct.new( :workflow_name, :workflow_arn, :description, :input_source_config, :output_source_config, :id_mapping_techniques, :created_at, :updated_at, :incremental_run_config, :role_arn, :tags) SENSITIVE = [] include Aws::Structure end |
#id_mapping_techniques ⇒ Types::IdMappingTechniques
An object which defines the ID mapping technique and any additional configurations.
1029 1030 1031 1032 1033 1034 1035 1036 1037 1038 1039 1040 1041 1042 1043 |
# File 'lib/aws-sdk-entityresolution/types.rb', line 1029 class GetIdMappingWorkflowOutput < Struct.new( :workflow_name, :workflow_arn, :description, :input_source_config, :output_source_config, :id_mapping_techniques, :created_at, :updated_at, :incremental_run_config, :role_arn, :tags) SENSITIVE = [] include Aws::Structure end |
#incremental_run_config ⇒ Types::IdMappingIncrementalRunConfig
The incremental run configuration for the ID mapping workflow.
1029 1030 1031 1032 1033 1034 1035 1036 1037 1038 1039 1040 1041 1042 1043 |
# File 'lib/aws-sdk-entityresolution/types.rb', line 1029 class GetIdMappingWorkflowOutput < Struct.new( :workflow_name, :workflow_arn, :description, :input_source_config, :output_source_config, :id_mapping_techniques, :created_at, :updated_at, :incremental_run_config, :role_arn, :tags) SENSITIVE = [] include Aws::Structure end |
#input_source_config ⇒ Array<Types::IdMappingWorkflowInputSource>
A list of ‘InputSource` objects, which have the fields `InputSourceARN` and `SchemaName`.
1029 1030 1031 1032 1033 1034 1035 1036 1037 1038 1039 1040 1041 1042 1043 |
# File 'lib/aws-sdk-entityresolution/types.rb', line 1029 class GetIdMappingWorkflowOutput < Struct.new( :workflow_name, :workflow_arn, :description, :input_source_config, :output_source_config, :id_mapping_techniques, :created_at, :updated_at, :incremental_run_config, :role_arn, :tags) SENSITIVE = [] include Aws::Structure end |
#output_source_config ⇒ Array<Types::IdMappingWorkflowOutputSource>
A list of ‘OutputSource` objects, each of which contains fields `outputS3Path` and `KMSArn`.
1029 1030 1031 1032 1033 1034 1035 1036 1037 1038 1039 1040 1041 1042 1043 |
# File 'lib/aws-sdk-entityresolution/types.rb', line 1029 class GetIdMappingWorkflowOutput < Struct.new( :workflow_name, :workflow_arn, :description, :input_source_config, :output_source_config, :id_mapping_techniques, :created_at, :updated_at, :incremental_run_config, :role_arn, :tags) SENSITIVE = [] include Aws::Structure end |
#role_arn ⇒ String
The Amazon Resource Name (ARN) of the IAM role. Entity Resolution assumes this role to access Amazon Web Services resources on your behalf.
1029 1030 1031 1032 1033 1034 1035 1036 1037 1038 1039 1040 1041 1042 1043 |
# File 'lib/aws-sdk-entityresolution/types.rb', line 1029 class GetIdMappingWorkflowOutput < Struct.new( :workflow_name, :workflow_arn, :description, :input_source_config, :output_source_config, :id_mapping_techniques, :created_at, :updated_at, :incremental_run_config, :role_arn, :tags) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Hash<String,String>
The tags used to organize, track, or control access for this resource.
1029 1030 1031 1032 1033 1034 1035 1036 1037 1038 1039 1040 1041 1042 1043 |
# File 'lib/aws-sdk-entityresolution/types.rb', line 1029 class GetIdMappingWorkflowOutput < Struct.new( :workflow_name, :workflow_arn, :description, :input_source_config, :output_source_config, :id_mapping_techniques, :created_at, :updated_at, :incremental_run_config, :role_arn, :tags) SENSITIVE = [] include Aws::Structure end |
#updated_at ⇒ Time
The timestamp of when the workflow was last updated.
1029 1030 1031 1032 1033 1034 1035 1036 1037 1038 1039 1040 1041 1042 1043 |
# File 'lib/aws-sdk-entityresolution/types.rb', line 1029 class GetIdMappingWorkflowOutput < Struct.new( :workflow_name, :workflow_arn, :description, :input_source_config, :output_source_config, :id_mapping_techniques, :created_at, :updated_at, :incremental_run_config, :role_arn, :tags) SENSITIVE = [] include Aws::Structure end |
#workflow_arn ⇒ String
The ARN (Amazon Resource Name) that Entity Resolution generated for the ‘IdMappingWorkflow` .
1029 1030 1031 1032 1033 1034 1035 1036 1037 1038 1039 1040 1041 1042 1043 |
# File 'lib/aws-sdk-entityresolution/types.rb', line 1029 class GetIdMappingWorkflowOutput < Struct.new( :workflow_name, :workflow_arn, :description, :input_source_config, :output_source_config, :id_mapping_techniques, :created_at, :updated_at, :incremental_run_config, :role_arn, :tags) SENSITIVE = [] include Aws::Structure end |
#workflow_name ⇒ String
The name of the workflow.
1029 1030 1031 1032 1033 1034 1035 1036 1037 1038 1039 1040 1041 1042 1043 |
# File 'lib/aws-sdk-entityresolution/types.rb', line 1029 class GetIdMappingWorkflowOutput < Struct.new( :workflow_name, :workflow_arn, :description, :input_source_config, :output_source_config, :id_mapping_techniques, :created_at, :updated_at, :incremental_run_config, :role_arn, :tags) SENSITIVE = [] include Aws::Structure end |