Method: Aws::EntityResolution::Types::GetIdNamespaceOutput#role_arn

Defined in:
lib/aws-sdk-entityresolution/types.rb

#role_arnString

The Amazon Resource Name (ARN) of the IAM role. Entity Resolution assumes this role to access the resources defined in this IdNamespace on your behalf as part of a workflow run.

Returns:

  • (String)


1111
1112
1113
1114
1115
1116
1117
1118
1119
1120
1121
1122
1123
1124
# File 'lib/aws-sdk-entityresolution/types.rb', line 1111

class GetIdNamespaceOutput < Struct.new(
  :id_namespace_name,
  :id_namespace_arn,
  :description,
  :input_source_config,
  :id_mapping_workflow_properties,
  :type,
  :role_arn,
  :created_at,
  :updated_at,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end