Class: Aws::EntityResolution::Types::GetMatchingWorkflowOutput
- Inherits:
-
Struct
- Object
- Struct
- Aws::EntityResolution::Types::GetMatchingWorkflowOutput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-entityresolution/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#created_at ⇒ Time
The timestamp of when the workflow was created.
-
#description ⇒ String
A description of the workflow.
-
#incremental_run_config ⇒ Types::IncrementalRunConfig
An object which defines an incremental run type and has only ‘incrementalRunType` as a field.
-
#input_source_config ⇒ Array<Types::InputSource>
A list of ‘InputSource` objects, which have the fields `InputSourceARN` and `SchemaName`.
-
#output_source_config ⇒ Array<Types::OutputSource>
A list of ‘OutputSource` objects, each of which contains fields `outputS3Path`, `applyNormalization`, `KMSArn`, and `output`.
-
#resolution_techniques ⇒ Types::ResolutionTechniques
An object which defines the ‘resolutionType` and the `ruleBasedProperties`.
-
#role_arn ⇒ String
The Amazon Resource Name (ARN) of the IAM role.
-
#tags ⇒ Hash<String,String>
The tags used to organize, track, or control access for this resource.
-
#updated_at ⇒ Time
The timestamp of when the workflow was last updated.
-
#workflow_arn ⇒ String
The ARN (Amazon Resource Name) that Entity Resolution generated for the ‘MatchingWorkflow`.
-
#workflow_name ⇒ String
The name of the workflow.
Instance Attribute Details
#created_at ⇒ Time
The timestamp of when the workflow was created.
1295 1296 1297 1298 1299 1300 1301 1302 1303 1304 1305 1306 1307 1308 1309 |
# File 'lib/aws-sdk-entityresolution/types.rb', line 1295 class GetMatchingWorkflowOutput < Struct.new( :workflow_name, :workflow_arn, :description, :input_source_config, :output_source_config, :resolution_techniques, :created_at, :updated_at, :incremental_run_config, :role_arn, :tags) SENSITIVE = [] include Aws::Structure end |
#description ⇒ String
A description of the workflow.
1295 1296 1297 1298 1299 1300 1301 1302 1303 1304 1305 1306 1307 1308 1309 |
# File 'lib/aws-sdk-entityresolution/types.rb', line 1295 class GetMatchingWorkflowOutput < Struct.new( :workflow_name, :workflow_arn, :description, :input_source_config, :output_source_config, :resolution_techniques, :created_at, :updated_at, :incremental_run_config, :role_arn, :tags) SENSITIVE = [] include Aws::Structure end |
#incremental_run_config ⇒ Types::IncrementalRunConfig
An object which defines an incremental run type and has only ‘incrementalRunType` as a field.
1295 1296 1297 1298 1299 1300 1301 1302 1303 1304 1305 1306 1307 1308 1309 |
# File 'lib/aws-sdk-entityresolution/types.rb', line 1295 class GetMatchingWorkflowOutput < Struct.new( :workflow_name, :workflow_arn, :description, :input_source_config, :output_source_config, :resolution_techniques, :created_at, :updated_at, :incremental_run_config, :role_arn, :tags) SENSITIVE = [] include Aws::Structure end |
#input_source_config ⇒ Array<Types::InputSource>
A list of ‘InputSource` objects, which have the fields `InputSourceARN` and `SchemaName`.
1295 1296 1297 1298 1299 1300 1301 1302 1303 1304 1305 1306 1307 1308 1309 |
# File 'lib/aws-sdk-entityresolution/types.rb', line 1295 class GetMatchingWorkflowOutput < Struct.new( :workflow_name, :workflow_arn, :description, :input_source_config, :output_source_config, :resolution_techniques, :created_at, :updated_at, :incremental_run_config, :role_arn, :tags) SENSITIVE = [] include Aws::Structure end |
#output_source_config ⇒ Array<Types::OutputSource>
A list of ‘OutputSource` objects, each of which contains fields `outputS3Path`, `applyNormalization`, `KMSArn`, and `output`.
1295 1296 1297 1298 1299 1300 1301 1302 1303 1304 1305 1306 1307 1308 1309 |
# File 'lib/aws-sdk-entityresolution/types.rb', line 1295 class GetMatchingWorkflowOutput < Struct.new( :workflow_name, :workflow_arn, :description, :input_source_config, :output_source_config, :resolution_techniques, :created_at, :updated_at, :incremental_run_config, :role_arn, :tags) SENSITIVE = [] include Aws::Structure end |
#resolution_techniques ⇒ Types::ResolutionTechniques
An object which defines the ‘resolutionType` and the `ruleBasedProperties`.
1295 1296 1297 1298 1299 1300 1301 1302 1303 1304 1305 1306 1307 1308 1309 |
# File 'lib/aws-sdk-entityresolution/types.rb', line 1295 class GetMatchingWorkflowOutput < Struct.new( :workflow_name, :workflow_arn, :description, :input_source_config, :output_source_config, :resolution_techniques, :created_at, :updated_at, :incremental_run_config, :role_arn, :tags) SENSITIVE = [] include Aws::Structure end |
#role_arn ⇒ String
The Amazon Resource Name (ARN) of the IAM role. Entity Resolution assumes this role to access Amazon Web Services resources on your behalf.
1295 1296 1297 1298 1299 1300 1301 1302 1303 1304 1305 1306 1307 1308 1309 |
# File 'lib/aws-sdk-entityresolution/types.rb', line 1295 class GetMatchingWorkflowOutput < Struct.new( :workflow_name, :workflow_arn, :description, :input_source_config, :output_source_config, :resolution_techniques, :created_at, :updated_at, :incremental_run_config, :role_arn, :tags) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Hash<String,String>
The tags used to organize, track, or control access for this resource.
1295 1296 1297 1298 1299 1300 1301 1302 1303 1304 1305 1306 1307 1308 1309 |
# File 'lib/aws-sdk-entityresolution/types.rb', line 1295 class GetMatchingWorkflowOutput < Struct.new( :workflow_name, :workflow_arn, :description, :input_source_config, :output_source_config, :resolution_techniques, :created_at, :updated_at, :incremental_run_config, :role_arn, :tags) SENSITIVE = [] include Aws::Structure end |
#updated_at ⇒ Time
The timestamp of when the workflow was last updated.
1295 1296 1297 1298 1299 1300 1301 1302 1303 1304 1305 1306 1307 1308 1309 |
# File 'lib/aws-sdk-entityresolution/types.rb', line 1295 class GetMatchingWorkflowOutput < Struct.new( :workflow_name, :workflow_arn, :description, :input_source_config, :output_source_config, :resolution_techniques, :created_at, :updated_at, :incremental_run_config, :role_arn, :tags) SENSITIVE = [] include Aws::Structure end |
#workflow_arn ⇒ String
The ARN (Amazon Resource Name) that Entity Resolution generated for the ‘MatchingWorkflow`.
1295 1296 1297 1298 1299 1300 1301 1302 1303 1304 1305 1306 1307 1308 1309 |
# File 'lib/aws-sdk-entityresolution/types.rb', line 1295 class GetMatchingWorkflowOutput < Struct.new( :workflow_name, :workflow_arn, :description, :input_source_config, :output_source_config, :resolution_techniques, :created_at, :updated_at, :incremental_run_config, :role_arn, :tags) SENSITIVE = [] include Aws::Structure end |
#workflow_name ⇒ String
The name of the workflow.
1295 1296 1297 1298 1299 1300 1301 1302 1303 1304 1305 1306 1307 1308 1309 |
# File 'lib/aws-sdk-entityresolution/types.rb', line 1295 class GetMatchingWorkflowOutput < Struct.new( :workflow_name, :workflow_arn, :description, :input_source_config, :output_source_config, :resolution_techniques, :created_at, :updated_at, :incremental_run_config, :role_arn, :tags) SENSITIVE = [] include Aws::Structure end |