Class: Aws::EntityResolution::Types::GetProviderServiceOutput

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-entityresolution/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#anonymized_outputBoolean

Specifies whether output data from the provider is anonymized. A value of TRUE means the output will be anonymized and you can't relate the data that comes back from the provider to the identifying input. A value of FALSE means the output won't be anonymized and you can relate the data that comes back from the provider to your source data.

Returns:



1432
1433
1434
1435
1436
1437
1438
1439
1440
1441
1442
1443
1444
1445
1446
1447
1448
# File 'lib/aws-sdk-entityresolution/types.rb', line 1432

class GetProviderServiceOutput < Struct.new(
  :provider_name,
  :provider_service_name,
  :provider_service_display_name,
  :provider_service_type,
  :provider_service_arn,
  :provider_configuration_definition,
  :provider_id_name_space_configuration,
  :provider_job_configuration,
  :provider_endpoint_configuration,
  :anonymized_output,
  :provider_entity_output_definition,
  :provider_intermediate_data_access_configuration,
  :provider_component_schema)
  SENSITIVE = []
  include Aws::Structure
end

#provider_component_schemaTypes::ProviderComponentSchema

Input schema for the provider service.

Returns:



1432
1433
1434
1435
1436
1437
1438
1439
1440
1441
1442
1443
1444
1445
1446
1447
1448
# File 'lib/aws-sdk-entityresolution/types.rb', line 1432

class GetProviderServiceOutput < Struct.new(
  :provider_name,
  :provider_service_name,
  :provider_service_display_name,
  :provider_service_type,
  :provider_service_arn,
  :provider_configuration_definition,
  :provider_id_name_space_configuration,
  :provider_job_configuration,
  :provider_endpoint_configuration,
  :anonymized_output,
  :provider_entity_output_definition,
  :provider_intermediate_data_access_configuration,
  :provider_component_schema)
  SENSITIVE = []
  include Aws::Structure
end

#provider_configuration_definitionHash, ...

The definition of the provider configuration.

Returns:



1432
1433
1434
1435
1436
1437
1438
1439
1440
1441
1442
1443
1444
1445
1446
1447
1448
# File 'lib/aws-sdk-entityresolution/types.rb', line 1432

class GetProviderServiceOutput < Struct.new(
  :provider_name,
  :provider_service_name,
  :provider_service_display_name,
  :provider_service_type,
  :provider_service_arn,
  :provider_configuration_definition,
  :provider_id_name_space_configuration,
  :provider_job_configuration,
  :provider_endpoint_configuration,
  :anonymized_output,
  :provider_entity_output_definition,
  :provider_intermediate_data_access_configuration,
  :provider_component_schema)
  SENSITIVE = []
  include Aws::Structure
end

#provider_endpoint_configurationTypes::ProviderEndpointConfiguration

The required configuration fields to use with the provider service.

Returns:



1432
1433
1434
1435
1436
1437
1438
1439
1440
1441
1442
1443
1444
1445
1446
1447
1448
# File 'lib/aws-sdk-entityresolution/types.rb', line 1432

class GetProviderServiceOutput < Struct.new(
  :provider_name,
  :provider_service_name,
  :provider_service_display_name,
  :provider_service_type,
  :provider_service_arn,
  :provider_configuration_definition,
  :provider_id_name_space_configuration,
  :provider_job_configuration,
  :provider_endpoint_configuration,
  :anonymized_output,
  :provider_entity_output_definition,
  :provider_intermediate_data_access_configuration,
  :provider_component_schema)
  SENSITIVE = []
  include Aws::Structure
end

#provider_entity_output_definitionHash, ...

The definition of the provider entity output.

Returns:



1432
1433
1434
1435
1436
1437
1438
1439
1440
1441
1442
1443
1444
1445
1446
1447
1448
# File 'lib/aws-sdk-entityresolution/types.rb', line 1432

class GetProviderServiceOutput < Struct.new(
  :provider_name,
  :provider_service_name,
  :provider_service_display_name,
  :provider_service_type,
  :provider_service_arn,
  :provider_configuration_definition,
  :provider_id_name_space_configuration,
  :provider_job_configuration,
  :provider_endpoint_configuration,
  :anonymized_output,
  :provider_entity_output_definition,
  :provider_intermediate_data_access_configuration,
  :provider_component_schema)
  SENSITIVE = []
  include Aws::Structure
end

#provider_id_name_space_configurationTypes::ProviderIdNameSpaceConfiguration

The provider configuration required for different ID namespace types.

Returns:



1432
1433
1434
1435
1436
1437
1438
1439
1440
1441
1442
1443
1444
1445
1446
1447
1448
# File 'lib/aws-sdk-entityresolution/types.rb', line 1432

class GetProviderServiceOutput < Struct.new(
  :provider_name,
  :provider_service_name,
  :provider_service_display_name,
  :provider_service_type,
  :provider_service_arn,
  :provider_configuration_definition,
  :provider_id_name_space_configuration,
  :provider_job_configuration,
  :provider_endpoint_configuration,
  :anonymized_output,
  :provider_entity_output_definition,
  :provider_intermediate_data_access_configuration,
  :provider_component_schema)
  SENSITIVE = []
  include Aws::Structure
end

#provider_intermediate_data_access_configurationTypes::ProviderIntermediateDataAccessConfiguration

The Amazon Web Services accounts and the S3 permissions that are required by some providers to create an S3 bucket for intermediate data storage.

Returns:



1432
1433
1434
1435
1436
1437
1438
1439
1440
1441
1442
1443
1444
1445
1446
1447
1448
# File 'lib/aws-sdk-entityresolution/types.rb', line 1432

class GetProviderServiceOutput < Struct.new(
  :provider_name,
  :provider_service_name,
  :provider_service_display_name,
  :provider_service_type,
  :provider_service_arn,
  :provider_configuration_definition,
  :provider_id_name_space_configuration,
  :provider_job_configuration,
  :provider_endpoint_configuration,
  :anonymized_output,
  :provider_entity_output_definition,
  :provider_intermediate_data_access_configuration,
  :provider_component_schema)
  SENSITIVE = []
  include Aws::Structure
end

#provider_job_configurationHash, ...

Provider service job configurations.

Returns:



1432
1433
1434
1435
1436
1437
1438
1439
1440
1441
1442
1443
1444
1445
1446
1447
1448
# File 'lib/aws-sdk-entityresolution/types.rb', line 1432

class GetProviderServiceOutput < Struct.new(
  :provider_name,
  :provider_service_name,
  :provider_service_display_name,
  :provider_service_type,
  :provider_service_arn,
  :provider_configuration_definition,
  :provider_id_name_space_configuration,
  :provider_job_configuration,
  :provider_endpoint_configuration,
  :anonymized_output,
  :provider_entity_output_definition,
  :provider_intermediate_data_access_configuration,
  :provider_component_schema)
  SENSITIVE = []
  include Aws::Structure
end

#provider_nameString

The name of the provider. This name is typically the company name.

Returns:



1432
1433
1434
1435
1436
1437
1438
1439
1440
1441
1442
1443
1444
1445
1446
1447
1448
# File 'lib/aws-sdk-entityresolution/types.rb', line 1432

class GetProviderServiceOutput < Struct.new(
  :provider_name,
  :provider_service_name,
  :provider_service_display_name,
  :provider_service_type,
  :provider_service_arn,
  :provider_configuration_definition,
  :provider_id_name_space_configuration,
  :provider_job_configuration,
  :provider_endpoint_configuration,
  :anonymized_output,
  :provider_entity_output_definition,
  :provider_intermediate_data_access_configuration,
  :provider_component_schema)
  SENSITIVE = []
  include Aws::Structure
end

#provider_service_arnString

The ARN (Amazon Resource Name) that Entity Resolution generated for the provider service.

Returns:



1432
1433
1434
1435
1436
1437
1438
1439
1440
1441
1442
1443
1444
1445
1446
1447
1448
# File 'lib/aws-sdk-entityresolution/types.rb', line 1432

class GetProviderServiceOutput < Struct.new(
  :provider_name,
  :provider_service_name,
  :provider_service_display_name,
  :provider_service_type,
  :provider_service_arn,
  :provider_configuration_definition,
  :provider_id_name_space_configuration,
  :provider_job_configuration,
  :provider_endpoint_configuration,
  :anonymized_output,
  :provider_entity_output_definition,
  :provider_intermediate_data_access_configuration,
  :provider_component_schema)
  SENSITIVE = []
  include Aws::Structure
end

#provider_service_display_nameString

The display name of the provider service.

Returns:



1432
1433
1434
1435
1436
1437
1438
1439
1440
1441
1442
1443
1444
1445
1446
1447
1448
# File 'lib/aws-sdk-entityresolution/types.rb', line 1432

class GetProviderServiceOutput < Struct.new(
  :provider_name,
  :provider_service_name,
  :provider_service_display_name,
  :provider_service_type,
  :provider_service_arn,
  :provider_configuration_definition,
  :provider_id_name_space_configuration,
  :provider_job_configuration,
  :provider_endpoint_configuration,
  :anonymized_output,
  :provider_entity_output_definition,
  :provider_intermediate_data_access_configuration,
  :provider_component_schema)
  SENSITIVE = []
  include Aws::Structure
end

#provider_service_nameString

The name of the product that the provider service provides.

Returns:



1432
1433
1434
1435
1436
1437
1438
1439
1440
1441
1442
1443
1444
1445
1446
1447
1448
# File 'lib/aws-sdk-entityresolution/types.rb', line 1432

class GetProviderServiceOutput < Struct.new(
  :provider_name,
  :provider_service_name,
  :provider_service_display_name,
  :provider_service_type,
  :provider_service_arn,
  :provider_configuration_definition,
  :provider_id_name_space_configuration,
  :provider_job_configuration,
  :provider_endpoint_configuration,
  :anonymized_output,
  :provider_entity_output_definition,
  :provider_intermediate_data_access_configuration,
  :provider_component_schema)
  SENSITIVE = []
  include Aws::Structure
end

#provider_service_typeString

The type of provider service.

Returns:



1432
1433
1434
1435
1436
1437
1438
1439
1440
1441
1442
1443
1444
1445
1446
1447
1448
# File 'lib/aws-sdk-entityresolution/types.rb', line 1432

class GetProviderServiceOutput < Struct.new(
  :provider_name,
  :provider_service_name,
  :provider_service_display_name,
  :provider_service_type,
  :provider_service_arn,
  :provider_configuration_definition,
  :provider_id_name_space_configuration,
  :provider_job_configuration,
  :provider_endpoint_configuration,
  :anonymized_output,
  :provider_entity_output_definition,
  :provider_intermediate_data_access_configuration,
  :provider_component_schema)
  SENSITIVE = []
  include Aws::Structure
end