Class: Aws::EntityResolution::Types::JobOutputSource
- Inherits:
-
Struct
- Object
- Struct
- Aws::EntityResolution::Types::JobOutputSource
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-entityresolution/types.rb
Overview
An object containing KMSArn, outputS3Path, and roleArn.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#kms_arn ⇒ String
Customer KMS ARN for encryption at rest.
-
#output_s3_path ⇒ String
The S3 path to which Entity Resolution will write the output table.
-
#role_arn ⇒ String
The Amazon Resource Name (ARN) of the IAM role.
Instance Attribute Details
#kms_arn ⇒ String
Customer KMS ARN for encryption at rest. If not provided, system will use an Entity Resolution managed KMS key.
2072 2073 2074 2075 2076 2077 2078 |
# File 'lib/aws-sdk-entityresolution/types.rb', line 2072 class JobOutputSource < Struct.new( :role_arn, :output_s3_path, :kms_arn) SENSITIVE = [] include Aws::Structure end |
#output_s3_path ⇒ String
The S3 path to which Entity Resolution will write the output table.
2072 2073 2074 2075 2076 2077 2078 |
# File 'lib/aws-sdk-entityresolution/types.rb', line 2072 class JobOutputSource < Struct.new( :role_arn, :output_s3_path, :kms_arn) SENSITIVE = [] include Aws::Structure end |
#role_arn ⇒ String
The Amazon Resource Name (ARN) of the IAM role. Entity Resolution assumes this role to access Amazon Web Services resources on your behalf as part of workflow execution.
2072 2073 2074 2075 2076 2077 2078 |
# File 'lib/aws-sdk-entityresolution/types.rb', line 2072 class JobOutputSource < Struct.new( :role_arn, :output_s3_path, :kms_arn) SENSITIVE = [] include Aws::Structure end |