Class: Aws::EntityResolution::Types::ListTagsForResourceOutput
- Inherits:
-
Struct
- Object
- Struct
- Aws::EntityResolution::Types::ListTagsForResourceOutput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-entityresolution/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#tags ⇒ Hash<String,String>
The tags used to organize, track, or control access for this resource.
Instance Attribute Details
#tags ⇒ Hash<String,String>
The tags used to organize, track, or control access for this resource.
2244 2245 2246 2247 2248 |
# File 'lib/aws-sdk-entityresolution/types.rb', line 2244 class ListTagsForResourceOutput < Struct.new( :tags) SENSITIVE = [] include Aws::Structure end |