Class: Aws::EntityResolution::Types::MatchingConfig

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-entityresolution/types.rb

Overview

An object that contains configuration settings for the matching process in a rule-based matching workflow.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#enable_transitive_matchingBoolean

Enables transitive matching for the rule-based matching workflow. When enabled, records that match through different rules are grouped together into the same match group.

Returns:

  • (Boolean)


2441
2442
2443
2444
2445
# File 'lib/aws-sdk-entityresolution/types.rb', line 2441

class MatchingConfig < Struct.new(
  :enable_transitive_matching)
  SENSITIVE = []
  include Aws::Structure
end