Class: Aws::EntityResolution::Types::OutputAttribute
- Inherits:
-
Struct
- Object
- Struct
- Aws::EntityResolution::Types::OutputAttribute
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-entityresolution/types.rb
Overview
A list of OutputAttribute objects, each of which have the fields
Name and Hashed. Each of these objects selects a column to be
included in the output table, and whether the values of the column
should be hashed.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#hashed ⇒ Boolean
Enables the ability to hash the column values in the output.
-
#name ⇒ String
A name of a column to be written to the output.
Instance Attribute Details
#hashed ⇒ Boolean
Enables the ability to hash the column values in the output.
2578 2579 2580 2581 2582 2583 |
# File 'lib/aws-sdk-entityresolution/types.rb', line 2578 class OutputAttribute < Struct.new( :name, :hashed) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
A name of a column to be written to the output. This must be an
InputField name in the schema mapping.
2578 2579 2580 2581 2582 2583 |
# File 'lib/aws-sdk-entityresolution/types.rb', line 2578 class OutputAttribute < Struct.new( :name, :hashed) SENSITIVE = [] include Aws::Structure end |