Class: Aws::EntityResolution::Types::ResolutionTechniques

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-entityresolution/types.rb

Overview

An object which defines the resolutionType and the ruleBasedProperties.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#enable_real_time_matchingBoolean

Specifies whether real-time matching is enabled for the rule-based matching workflow. When you enable real-time matching, you can use the GenerateMatchId operation with the workflow.

Returns:

  • (Boolean)


2964
2965
2966
2967
2968
2969
2970
2971
2972
# File 'lib/aws-sdk-entityresolution/types.rb', line 2964

class ResolutionTechniques < Struct.new(
  :resolution_type,
  :rule_based_properties,
  :rule_condition_properties,
  :enable_real_time_matching,
  :provider_properties)
  SENSITIVE = []
  include Aws::Structure
end

#provider_propertiesTypes::ProviderProperties

The properties of the provider service.



2964
2965
2966
2967
2968
2969
2970
2971
2972
# File 'lib/aws-sdk-entityresolution/types.rb', line 2964

class ResolutionTechniques < Struct.new(
  :resolution_type,
  :rule_based_properties,
  :rule_condition_properties,
  :enable_real_time_matching,
  :provider_properties)
  SENSITIVE = []
  include Aws::Structure
end

#resolution_typeString

The type of matching workflow to create. Specify one of the following types:

  • RULE_MATCHING: Match records using configurable rule-based criteria

  • ML_MATCHING: Match records using machine learning models

  • PROVIDER: Match records using a third-party matching provider

Returns:

  • (String)


2964
2965
2966
2967
2968
2969
2970
2971
2972
# File 'lib/aws-sdk-entityresolution/types.rb', line 2964

class ResolutionTechniques < Struct.new(
  :resolution_type,
  :rule_based_properties,
  :rule_condition_properties,
  :enable_real_time_matching,
  :provider_properties)
  SENSITIVE = []
  include Aws::Structure
end

#rule_based_propertiesTypes::RuleBasedProperties

An object which defines the list of matching rules to run and has a field rules, which is a list of rule objects.



2964
2965
2966
2967
2968
2969
2970
2971
2972
# File 'lib/aws-sdk-entityresolution/types.rb', line 2964

class ResolutionTechniques < Struct.new(
  :resolution_type,
  :rule_based_properties,
  :rule_condition_properties,
  :enable_real_time_matching,
  :provider_properties)
  SENSITIVE = []
  include Aws::Structure
end

#rule_condition_propertiesTypes::RuleConditionProperties

An object containing the rules for a matching workflow.



2964
2965
2966
2967
2968
2969
2970
2971
2972
# File 'lib/aws-sdk-entityresolution/types.rb', line 2964

class ResolutionTechniques < Struct.new(
  :resolution_type,
  :rule_based_properties,
  :rule_condition_properties,
  :enable_real_time_matching,
  :provider_properties)
  SENSITIVE = []
  include Aws::Structure
end