Class: Aws::EntityResolution::Types::StartIdMappingJobInput

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-entityresolution/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#job_typeString

The job type for the ID mapping job.

If the jobType value is set to INCREMENTAL, only new or changed data is processed since the last job run. This is the default value if the CreateIdMappingWorkflow API is configured with an incrementalRunConfig.

If the jobType value is set to BATCH, all data is processed from the input source, regardless of previous job runs. This is the default value if the CreateIdMappingWorkflow API isn't configured with an incrementalRunConfig.

If the jobType value is set to DELETE_ONLY, only deletion requests from BatchDeleteUniqueIds are processed.

Returns:

  • (String)


3265
3266
3267
3268
3269
3270
3271
# File 'lib/aws-sdk-entityresolution/types.rb', line 3265

class StartIdMappingJobInput < Struct.new(
  :workflow_name,
  :output_source_config,
  :job_type)
  SENSITIVE = []
  include Aws::Structure
end

#output_source_configArray<Types::IdMappingJobOutputSource>

A list of OutputSource objects.



3265
3266
3267
3268
3269
3270
3271
# File 'lib/aws-sdk-entityresolution/types.rb', line 3265

class StartIdMappingJobInput < Struct.new(
  :workflow_name,
  :output_source_config,
  :job_type)
  SENSITIVE = []
  include Aws::Structure
end

#workflow_nameString

The name of the ID mapping job to be retrieved.

Returns:

  • (String)


3265
3266
3267
3268
3269
3270
3271
# File 'lib/aws-sdk-entityresolution/types.rb', line 3265

class StartIdMappingJobInput < Struct.new(
  :workflow_name,
  :output_source_config,
  :job_type)
  SENSITIVE = []
  include Aws::Structure
end