Class: Aws::EntityResolution::Types::StartIdMappingJobOutput
- Inherits:
-
Struct
- Object
- Struct
- Aws::EntityResolution::Types::StartIdMappingJobOutput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-entityresolution/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#job_id ⇒ String
The ID of the job.
-
#job_type ⇒ String
The job type for the started ID mapping job.
-
#output_source_config ⇒ Array<Types::IdMappingJobOutputSource>
A list of
OutputSourceobjects.
Instance Attribute Details
#job_id ⇒ String
The ID of the job.
3299 3300 3301 3302 3303 3304 3305 |
# File 'lib/aws-sdk-entityresolution/types.rb', line 3299 class StartIdMappingJobOutput < Struct.new( :job_id, :output_source_config, :job_type) SENSITIVE = [] include Aws::Structure end |
#job_type ⇒ String
The job type for the started ID mapping job.
A value of INCREMENTAL indicates that only new or changed data was
processed since the last job run. This is the default job type if
the workflow was created with an incrementalRunConfig.
A value of BATCH indicates that all data was processed from the
input source, regardless of previous job runs. This is the default
job type if the workflow wasn't created with an
incrementalRunConfig.
A value of DELETE_ONLY indicates that only deletion requests from
BatchDeleteUniqueIds were processed.
3299 3300 3301 3302 3303 3304 3305 |
# File 'lib/aws-sdk-entityresolution/types.rb', line 3299 class StartIdMappingJobOutput < Struct.new( :job_id, :output_source_config, :job_type) SENSITIVE = [] include Aws::Structure end |
#output_source_config ⇒ Array<Types::IdMappingJobOutputSource>
A list of OutputSource objects.
3299 3300 3301 3302 3303 3304 3305 |
# File 'lib/aws-sdk-entityresolution/types.rb', line 3299 class StartIdMappingJobOutput < Struct.new( :job_id, :output_source_config, :job_type) SENSITIVE = [] include Aws::Structure end |