Class: Aws::EntityResolution::Types::UpdateMatchingWorkflowOutput
- Inherits:
-
Struct
- Object
- Struct
- Aws::EntityResolution::Types::UpdateMatchingWorkflowOutput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-entityresolution/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#description ⇒ String
A description of the workflow.
-
#incremental_run_config ⇒ Types::IncrementalRunConfig
An object which defines an incremental run type and has only
incrementalRunTypeas a field. -
#input_source_config ⇒ Array<Types::InputSource>
A list of
InputSourceobjects, which have the fieldsInputSourceARNandSchemaName. -
#output_source_config ⇒ Array<Types::OutputSource>
A list of
OutputSourceobjects, each of which contains fieldsoutputS3Path,applyNormalization,KMSArn, andoutput. -
#resolution_techniques ⇒ Types::ResolutionTechniques
An object which defines the
resolutionTypeand theruleBasedProperties. -
#role_arn ⇒ String
The Amazon Resource Name (ARN) of the IAM role.
-
#workflow_name ⇒ String
The name of the workflow.
Instance Attribute Details
#description ⇒ String
A description of the workflow.
3677 3678 3679 3680 3681 3682 3683 3684 3685 3686 3687 |
# File 'lib/aws-sdk-entityresolution/types.rb', line 3677 class UpdateMatchingWorkflowOutput < Struct.new( :workflow_name, :description, :input_source_config, :output_source_config, :resolution_techniques, :incremental_run_config, :role_arn) SENSITIVE = [] include Aws::Structure end |
#incremental_run_config ⇒ Types::IncrementalRunConfig
An object which defines an incremental run type and has only
incrementalRunType as a field.
3677 3678 3679 3680 3681 3682 3683 3684 3685 3686 3687 |
# File 'lib/aws-sdk-entityresolution/types.rb', line 3677 class UpdateMatchingWorkflowOutput < Struct.new( :workflow_name, :description, :input_source_config, :output_source_config, :resolution_techniques, :incremental_run_config, :role_arn) SENSITIVE = [] include Aws::Structure end |
#input_source_config ⇒ Array<Types::InputSource>
A list of InputSource objects, which have the fields
InputSourceARN and SchemaName.
3677 3678 3679 3680 3681 3682 3683 3684 3685 3686 3687 |
# File 'lib/aws-sdk-entityresolution/types.rb', line 3677 class UpdateMatchingWorkflowOutput < Struct.new( :workflow_name, :description, :input_source_config, :output_source_config, :resolution_techniques, :incremental_run_config, :role_arn) SENSITIVE = [] include Aws::Structure end |
#output_source_config ⇒ Array<Types::OutputSource>
A list of OutputSource objects, each of which contains fields
outputS3Path, applyNormalization, KMSArn, and output.
3677 3678 3679 3680 3681 3682 3683 3684 3685 3686 3687 |
# File 'lib/aws-sdk-entityresolution/types.rb', line 3677 class UpdateMatchingWorkflowOutput < Struct.new( :workflow_name, :description, :input_source_config, :output_source_config, :resolution_techniques, :incremental_run_config, :role_arn) SENSITIVE = [] include Aws::Structure end |
#resolution_techniques ⇒ Types::ResolutionTechniques
An object which defines the resolutionType and the
ruleBasedProperties.
3677 3678 3679 3680 3681 3682 3683 3684 3685 3686 3687 |
# File 'lib/aws-sdk-entityresolution/types.rb', line 3677 class UpdateMatchingWorkflowOutput < Struct.new( :workflow_name, :description, :input_source_config, :output_source_config, :resolution_techniques, :incremental_run_config, :role_arn) SENSITIVE = [] include Aws::Structure end |
#role_arn ⇒ String
The Amazon Resource Name (ARN) of the IAM role. Entity Resolution assumes this role to create resources on your behalf as part of workflow execution.
3677 3678 3679 3680 3681 3682 3683 3684 3685 3686 3687 |
# File 'lib/aws-sdk-entityresolution/types.rb', line 3677 class UpdateMatchingWorkflowOutput < Struct.new( :workflow_name, :description, :input_source_config, :output_source_config, :resolution_techniques, :incremental_run_config, :role_arn) SENSITIVE = [] include Aws::Structure end |
#workflow_name ⇒ String
The name of the workflow.
3677 3678 3679 3680 3681 3682 3683 3684 3685 3686 3687 |
# File 'lib/aws-sdk-entityresolution/types.rb', line 3677 class UpdateMatchingWorkflowOutput < Struct.new( :workflow_name, :description, :input_source_config, :output_source_config, :resolution_techniques, :incremental_run_config, :role_arn) SENSITIVE = [] include Aws::Structure end |