Class: Aws::EntityResolution::Client
- Inherits:
-
Seahorse::Client::Base
- Object
- Seahorse::Client::Base
- Aws::EntityResolution::Client
- Includes:
- ClientStubs
- Defined in:
- lib/aws-sdk-entityresolution/client.rb
Overview
An API client for EntityResolution. To construct a client, you need to configure a ‘:region` and `:credentials`.
client = Aws::EntityResolution::Client.new(
region: region_name,
credentials: credentials,
# ...
)
For details on configuring region and credentials see the [developer guide](/sdk-for-ruby/v3/developer-guide/setup-config.html).
See #initialize for a full list of supported configuration options.
Class Attribute Summary collapse
- .identifier ⇒ Object readonly private
API Operations collapse
-
#add_policy_statement(params = {}) ⇒ Types::AddPolicyStatementOutput
Adds a policy statement object.
-
#batch_delete_unique_id(params = {}) ⇒ Types::BatchDeleteUniqueIdOutput
Deletes multiple unique IDs in a matching workflow.
-
#create_id_mapping_workflow(params = {}) ⇒ Types::CreateIdMappingWorkflowOutput
Creates an ‘IdMappingWorkflow` object which stores the configuration of the data processing job to be run.
-
#create_id_namespace(params = {}) ⇒ Types::CreateIdNamespaceOutput
Creates an ID namespace object which will help customers provide metadata explaining their dataset and how to use it.
-
#create_matching_workflow(params = {}) ⇒ Types::CreateMatchingWorkflowOutput
Creates a matching workflow that defines the configuration for a data processing job.
-
#create_schema_mapping(params = {}) ⇒ Types::CreateSchemaMappingOutput
Creates a schema mapping, which defines the schema of the input customer records table.
-
#delete_id_mapping_workflow(params = {}) ⇒ Types::DeleteIdMappingWorkflowOutput
Deletes the ‘IdMappingWorkflow` with a given name.
-
#delete_id_namespace(params = {}) ⇒ Types::DeleteIdNamespaceOutput
Deletes the ‘IdNamespace` with a given name.
-
#delete_matching_workflow(params = {}) ⇒ Types::DeleteMatchingWorkflowOutput
Deletes the ‘MatchingWorkflow` with a given name.
-
#delete_policy_statement(params = {}) ⇒ Types::DeletePolicyStatementOutput
Deletes the policy statement.
-
#delete_schema_mapping(params = {}) ⇒ Types::DeleteSchemaMappingOutput
Deletes the ‘SchemaMapping` with a given name.
-
#generate_match_id(params = {}) ⇒ Types::GenerateMatchIdOutput
Generates or retrieves Match IDs for records using a rule-based matching workflow.
-
#get_id_mapping_job(params = {}) ⇒ Types::GetIdMappingJobOutput
Returns the status, metrics, and errors (if there are any) that are associated with a job.
-
#get_id_mapping_workflow(params = {}) ⇒ Types::GetIdMappingWorkflowOutput
Returns the ‘IdMappingWorkflow` with a given name, if it exists.
-
#get_id_namespace(params = {}) ⇒ Types::GetIdNamespaceOutput
Returns the ‘IdNamespace` with a given name, if it exists.
-
#get_match_id(params = {}) ⇒ Types::GetMatchIdOutput
Returns the corresponding Match ID of a customer record if the record has been processed in a rule-based matching workflow.
-
#get_matching_job(params = {}) ⇒ Types::GetMatchingJobOutput
Returns the status, metrics, and errors (if there are any) that are associated with a job.
-
#get_matching_workflow(params = {}) ⇒ Types::GetMatchingWorkflowOutput
Returns the ‘MatchingWorkflow` with a given name, if it exists.
-
#get_policy(params = {}) ⇒ Types::GetPolicyOutput
Returns the resource-based policy.
-
#get_provider_service(params = {}) ⇒ Types::GetProviderServiceOutput
Returns the ‘ProviderService` of a given name.
-
#get_schema_mapping(params = {}) ⇒ Types::GetSchemaMappingOutput
Returns the SchemaMapping of a given name.
-
#list_id_mapping_jobs(params = {}) ⇒ Types::ListIdMappingJobsOutput
Lists all ID mapping jobs for a given workflow.
-
#list_id_mapping_workflows(params = {}) ⇒ Types::ListIdMappingWorkflowsOutput
Returns a list of all the ‘IdMappingWorkflows` that have been created for an Amazon Web Services account.
-
#list_id_namespaces(params = {}) ⇒ Types::ListIdNamespacesOutput
Returns a list of all ID namespaces.
-
#list_matching_jobs(params = {}) ⇒ Types::ListMatchingJobsOutput
Lists all jobs for a given workflow.
-
#list_matching_workflows(params = {}) ⇒ Types::ListMatchingWorkflowsOutput
Returns a list of all the ‘MatchingWorkflows` that have been created for an Amazon Web Services account.
-
#list_provider_services(params = {}) ⇒ Types::ListProviderServicesOutput
Returns a list of all the ‘ProviderServices` that are available in this Amazon Web Services Region.
-
#list_schema_mappings(params = {}) ⇒ Types::ListSchemaMappingsOutput
Returns a list of all the ‘SchemaMappings` that have been created for an Amazon Web Services account.
-
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceOutput
Displays the tags associated with an Entity Resolution resource.
-
#put_policy(params = {}) ⇒ Types::PutPolicyOutput
Updates the resource-based policy.
-
#start_id_mapping_job(params = {}) ⇒ Types::StartIdMappingJobOutput
Starts the ‘IdMappingJob` of a workflow.
-
#start_matching_job(params = {}) ⇒ Types::StartMatchingJobOutput
Starts the ‘MatchingJob` of a workflow.
-
#tag_resource(params = {}) ⇒ Struct
Assigns one or more tags (key-value pairs) to the specified Entity Resolution resource.
-
#untag_resource(params = {}) ⇒ Struct
Removes one or more tags from the specified Entity Resolution resource.
-
#update_id_mapping_workflow(params = {}) ⇒ Types::UpdateIdMappingWorkflowOutput
Updates an existing ‘IdMappingWorkflow`.
-
#update_id_namespace(params = {}) ⇒ Types::UpdateIdNamespaceOutput
Updates an existing ID namespace.
-
#update_matching_workflow(params = {}) ⇒ Types::UpdateMatchingWorkflowOutput
Updates an existing matching workflow.
-
#update_schema_mapping(params = {}) ⇒ Types::UpdateSchemaMappingOutput
Updates a schema mapping.
Class Method Summary collapse
- .errors_module ⇒ Object private
Instance Method Summary collapse
- #build_request(operation_name, params = {}) ⇒ Object private
-
#initialize(options) ⇒ Client
constructor
A new instance of Client.
- #waiter_names ⇒ Object deprecated private Deprecated.
Constructor Details
#initialize(options) ⇒ Client
Returns a new instance of Client.
471 472 473 |
# File 'lib/aws-sdk-entityresolution/client.rb', line 471 def initialize(*args) super end |
Class Attribute Details
.identifier ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
2840 2841 2842 |
# File 'lib/aws-sdk-entityresolution/client.rb', line 2840 def identifier @identifier end |
Class Method Details
.errors_module ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
2843 2844 2845 |
# File 'lib/aws-sdk-entityresolution/client.rb', line 2843 def errors_module Errors end |
Instance Method Details
#add_policy_statement(params = {}) ⇒ Types::AddPolicyStatementOutput
Adds a policy statement object. To retrieve a list of existing policy statements, use the ‘GetPolicy` API.
537 538 539 540 |
# File 'lib/aws-sdk-entityresolution/client.rb', line 537 def add_policy_statement(params = {}, = {}) req = build_request(:add_policy_statement, params) req.send_request() end |
#batch_delete_unique_id(params = {}) ⇒ Types::BatchDeleteUniqueIdOutput
Deletes multiple unique IDs in a matching workflow.
583 584 585 586 |
# File 'lib/aws-sdk-entityresolution/client.rb', line 583 def batch_delete_unique_id(params = {}, = {}) req = build_request(:batch_delete_unique_id, params) req.send_request() end |
#build_request(operation_name, params = {}) ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
2813 2814 2815 2816 2817 2818 2819 2820 2821 2822 2823 2824 2825 2826 2827 2828 2829 |
# File 'lib/aws-sdk-entityresolution/client.rb', line 2813 def build_request(operation_name, params = {}) handlers = @handlers.for(operation_name) tracer = config.telemetry_provider.tracer_provider.tracer( Aws::Telemetry.module_to_tracer_name('Aws::EntityResolution') ) context = Seahorse::Client::RequestContext.new( operation_name: operation_name, operation: config.api.operation(operation_name), client: self, params: params, config: config, tracer: tracer ) context[:gem_name] = 'aws-sdk-entityresolution' context[:gem_version] = '1.49.0' Seahorse::Client::Request.new(handlers, context) end |
#create_id_mapping_workflow(params = {}) ⇒ Types::CreateIdMappingWorkflowOutput
Creates an ‘IdMappingWorkflow` object which stores the configuration of the data processing job to be run. Each `IdMappingWorkflow` must have a unique workflow name. To modify an existing workflow, use the UpdateIdMappingWorkflow API.
Incremental processing is not supported for ID mapping workflows.
714 715 716 717 |
# File 'lib/aws-sdk-entityresolution/client.rb', line 714 def create_id_mapping_workflow(params = {}, = {}) req = build_request(:create_id_mapping_workflow, params) req.send_request() end |
#create_id_namespace(params = {}) ⇒ Types::CreateIdNamespaceOutput
Creates an ID namespace object which will help customers provide metadata explaining their dataset and how to use it. Each ID namespace must have a unique name. To modify an existing ID namespace, use the UpdateIdNamespace API.
838 839 840 841 |
# File 'lib/aws-sdk-entityresolution/client.rb', line 838 def create_id_namespace(params = {}, = {}) req = build_request(:create_id_namespace, params) req.send_request() end |
#create_matching_workflow(params = {}) ⇒ Types::CreateMatchingWorkflowOutput
Creates a matching workflow that defines the configuration for a data processing job. The workflow name must be unique. To modify an existing workflow, use ‘UpdateMatchingWorkflow`.
For workflows where ‘resolutionType` is `ML_MATCHING` or `PROVIDER`, incremental processing is not supported.
1004 1005 1006 1007 |
# File 'lib/aws-sdk-entityresolution/client.rb', line 1004 def create_matching_workflow(params = {}, = {}) req = build_request(:create_matching_workflow, params) req.send_request() end |
#create_schema_mapping(params = {}) ⇒ Types::CreateSchemaMappingOutput
Creates a schema mapping, which defines the schema of the input customer records table. The ‘SchemaMapping` also provides Entity Resolution with some metadata about the table, such as the attribute types of the columns and which columns to match on.
1073 1074 1075 1076 |
# File 'lib/aws-sdk-entityresolution/client.rb', line 1073 def create_schema_mapping(params = {}, = {}) req = build_request(:create_schema_mapping, params) req.send_request() end |
#delete_id_mapping_workflow(params = {}) ⇒ Types::DeleteIdMappingWorkflowOutput
Deletes the ‘IdMappingWorkflow` with a given name. This operation will succeed even if a workflow with the given name does not exist.
1102 1103 1104 1105 |
# File 'lib/aws-sdk-entityresolution/client.rb', line 1102 def delete_id_mapping_workflow(params = {}, = {}) req = build_request(:delete_id_mapping_workflow, params) req.send_request() end |
#delete_id_namespace(params = {}) ⇒ Types::DeleteIdNamespaceOutput
Deletes the ‘IdNamespace` with a given name.
1130 1131 1132 1133 |
# File 'lib/aws-sdk-entityresolution/client.rb', line 1130 def delete_id_namespace(params = {}, = {}) req = build_request(:delete_id_namespace, params) req.send_request() end |
#delete_matching_workflow(params = {}) ⇒ Types::DeleteMatchingWorkflowOutput
Deletes the ‘MatchingWorkflow` with a given name. This operation will succeed even if a workflow with the given name does not exist.
1159 1160 1161 1162 |
# File 'lib/aws-sdk-entityresolution/client.rb', line 1159 def delete_matching_workflow(params = {}, = {}) req = build_request(:delete_matching_workflow, params) req.send_request() end |
#delete_policy_statement(params = {}) ⇒ Types::DeletePolicyStatementOutput
Deletes the policy statement.
1196 1197 1198 1199 |
# File 'lib/aws-sdk-entityresolution/client.rb', line 1196 def delete_policy_statement(params = {}, = {}) req = build_request(:delete_policy_statement, params) req.send_request() end |
#delete_schema_mapping(params = {}) ⇒ Types::DeleteSchemaMappingOutput
Deletes the ‘SchemaMapping` with a given name. This operation will succeed even if a schema with the given name does not exist. This operation will fail if there is a `MatchingWorkflow` object that references the `SchemaMapping` in the workflow’s ‘InputSourceConfig`.
1227 1228 1229 1230 |
# File 'lib/aws-sdk-entityresolution/client.rb', line 1227 def delete_schema_mapping(params = {}, = {}) req = build_request(:delete_schema_mapping, params) req.send_request() end |
#generate_match_id(params = {}) ⇒ Types::GenerateMatchIdOutput
Generates or retrieves Match IDs for records using a rule-based matching workflow. When you call this operation, it processes your records against the workflow’s matching rules to identify potential matches. For existing records, it retrieves their Match IDs and associated rules. For records without matches, it generates new Match IDs. The operation saves results to Amazon S3.
The processing type (‘processingType`) you choose affects both the accuracy and response time of the operation. Additional charges apply for each API call, whether made through the Entity Resolution console or directly via the API. The rule-based matching workflow must exist and be active before calling this operation.
1310 1311 1312 1313 |
# File 'lib/aws-sdk-entityresolution/client.rb', line 1310 def generate_match_id(params = {}, = {}) req = build_request(:generate_match_id, params) req.send_request() end |
#get_id_mapping_job(params = {}) ⇒ Types::GetIdMappingJobOutput
Returns the status, metrics, and errors (if there are any) that are associated with a job.
1374 1375 1376 1377 |
# File 'lib/aws-sdk-entityresolution/client.rb', line 1374 def get_id_mapping_job(params = {}, = {}) req = build_request(:get_id_mapping_job, params) req.send_request() end |
#get_id_mapping_workflow(params = {}) ⇒ Types::GetIdMappingWorkflowOutput
Returns the ‘IdMappingWorkflow` with a given name, if it exists.
1437 1438 1439 1440 |
# File 'lib/aws-sdk-entityresolution/client.rb', line 1437 def get_id_mapping_workflow(params = {}, = {}) req = build_request(:get_id_mapping_workflow, params) req.send_request() end |
#get_id_namespace(params = {}) ⇒ Types::GetIdNamespaceOutput
Returns the ‘IdNamespace` with a given name, if it exists.
1497 1498 1499 1500 |
# File 'lib/aws-sdk-entityresolution/client.rb', line 1497 def get_id_namespace(params = {}, = {}) req = build_request(:get_id_namespace, params) req.send_request() end |
#get_match_id(params = {}) ⇒ Types::GetMatchIdOutput
Returns the corresponding Match ID of a customer record if the record has been processed in a rule-based matching workflow.
You can call this API as a dry run of an incremental load on the rule-based matching workflow.
1544 1545 1546 1547 |
# File 'lib/aws-sdk-entityresolution/client.rb', line 1544 def get_match_id(params = {}, = {}) req = build_request(:get_match_id, params) req.send_request() end |
#get_matching_job(params = {}) ⇒ Types::GetMatchingJobOutput
Returns the status, metrics, and errors (if there are any) that are associated with a job.
1596 1597 1598 1599 |
# File 'lib/aws-sdk-entityresolution/client.rb', line 1596 def get_matching_job(params = {}, = {}) req = build_request(:get_matching_job, params) req.send_request() end |
#get_matching_workflow(params = {}) ⇒ Types::GetMatchingWorkflowOutput
Returns the ‘MatchingWorkflow` with a given name, if it exists.
1668 1669 1670 1671 |
# File 'lib/aws-sdk-entityresolution/client.rb', line 1668 def get_matching_workflow(params = {}, = {}) req = build_request(:get_matching_workflow, params) req.send_request() end |
#get_policy(params = {}) ⇒ Types::GetPolicyOutput
Returns the resource-based policy.
1701 1702 1703 1704 |
# File 'lib/aws-sdk-entityresolution/client.rb', line 1701 def get_policy(params = {}, = {}) req = build_request(:get_policy, params) req.send_request() end |
#get_provider_service(params = {}) ⇒ Types::GetProviderServiceOutput
Returns the ‘ProviderService` of a given name.
1768 1769 1770 1771 |
# File 'lib/aws-sdk-entityresolution/client.rb', line 1768 def get_provider_service(params = {}, = {}) req = build_request(:get_provider_service, params) req.send_request() end |
#get_schema_mapping(params = {}) ⇒ Types::GetSchemaMappingOutput
Returns the SchemaMapping of a given name.
1817 1818 1819 1820 |
# File 'lib/aws-sdk-entityresolution/client.rb', line 1817 def get_schema_mapping(params = {}, = {}) req = build_request(:get_schema_mapping, params) req.send_request() end |
#list_id_mapping_jobs(params = {}) ⇒ Types::ListIdMappingJobsOutput
Lists all ID mapping jobs for a given workflow.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1861 1862 1863 1864 |
# File 'lib/aws-sdk-entityresolution/client.rb', line 1861 def list_id_mapping_jobs(params = {}, = {}) req = build_request(:list_id_mapping_jobs, params) req.send_request() end |
#list_id_mapping_workflows(params = {}) ⇒ Types::ListIdMappingWorkflowsOutput
Returns a list of all the ‘IdMappingWorkflows` that have been created for an Amazon Web Services account.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1902 1903 1904 1905 |
# File 'lib/aws-sdk-entityresolution/client.rb', line 1902 def list_id_mapping_workflows(params = {}, = {}) req = build_request(:list_id_mapping_workflows, params) req.send_request() end |
#list_id_namespaces(params = {}) ⇒ Types::ListIdNamespacesOutput
Returns a list of all ID namespaces.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1946 1947 1948 1949 |
# File 'lib/aws-sdk-entityresolution/client.rb', line 1946 def list_id_namespaces(params = {}, = {}) req = build_request(:list_id_namespaces, params) req.send_request() end |
#list_matching_jobs(params = {}) ⇒ Types::ListMatchingJobsOutput
Lists all jobs for a given workflow.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1990 1991 1992 1993 |
# File 'lib/aws-sdk-entityresolution/client.rb', line 1990 def list_matching_jobs(params = {}, = {}) req = build_request(:list_matching_jobs, params) req.send_request() end |
#list_matching_workflows(params = {}) ⇒ Types::ListMatchingWorkflowsOutput
Returns a list of all the ‘MatchingWorkflows` that have been created for an Amazon Web Services account.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
2032 2033 2034 2035 |
# File 'lib/aws-sdk-entityresolution/client.rb', line 2032 def list_matching_workflows(params = {}, = {}) req = build_request(:list_matching_workflows, params) req.send_request() end |
#list_provider_services(params = {}) ⇒ Types::ListProviderServicesOutput
Returns a list of all the ‘ProviderServices` that are available in this Amazon Web Services Region.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
2078 2079 2080 2081 |
# File 'lib/aws-sdk-entityresolution/client.rb', line 2078 def list_provider_services(params = {}, = {}) req = build_request(:list_provider_services, params) req.send_request() end |
#list_schema_mappings(params = {}) ⇒ Types::ListSchemaMappingsOutput
Returns a list of all the ‘SchemaMappings` that have been created for an Amazon Web Services account.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
2120 2121 2122 2123 |
# File 'lib/aws-sdk-entityresolution/client.rb', line 2120 def list_schema_mappings(params = {}, = {}) req = build_request(:list_schema_mappings, params) req.send_request() end |
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceOutput
Displays the tags associated with an Entity Resolution resource. In Entity Resolution, ‘SchemaMapping`, and `MatchingWorkflow` can be tagged.
2151 2152 2153 2154 |
# File 'lib/aws-sdk-entityresolution/client.rb', line 2151 def (params = {}, = {}) req = build_request(:list_tags_for_resource, params) req.send_request() end |
#put_policy(params = {}) ⇒ Types::PutPolicyOutput
Updates the resource-based policy.
2197 2198 2199 2200 |
# File 'lib/aws-sdk-entityresolution/client.rb', line 2197 def put_policy(params = {}, = {}) req = build_request(:put_policy, params) req.send_request() end |
#start_id_mapping_job(params = {}) ⇒ Types::StartIdMappingJobOutput
Starts the ‘IdMappingJob` of a workflow. The workflow must have previously been created using the `CreateIdMappingWorkflow` endpoint.
2260 2261 2262 2263 |
# File 'lib/aws-sdk-entityresolution/client.rb', line 2260 def start_id_mapping_job(params = {}, = {}) req = build_request(:start_id_mapping_job, params) req.send_request() end |
#start_matching_job(params = {}) ⇒ Types::StartMatchingJobOutput
Starts the ‘MatchingJob` of a workflow. The workflow must have previously been created using the `CreateMatchingWorkflow` endpoint.
2289 2290 2291 2292 |
# File 'lib/aws-sdk-entityresolution/client.rb', line 2289 def start_matching_job(params = {}, = {}) req = build_request(:start_matching_job, params) req.send_request() end |
#tag_resource(params = {}) ⇒ Struct
Assigns one or more tags (key-value pairs) to the specified Entity Resolution resource. Tags can help you organize and categorize your resources. You can also use them to scope user permissions by granting a user permission to access or change only resources with certain tag values. In Entity Resolution, ‘SchemaMapping` and `MatchingWorkflow` can be tagged. Tags don’t have any semantic meaning to Amazon Web Services and are interpreted strictly as strings of characters. You can use the ‘TagResource` action with a resource that already has tags. If you specify a new tag key, this tag is appended to the list of tags associated with the resource. If you specify a tag key that is already associated with the resource, the new tag value that you specify replaces the previous value for that tag.
2328 2329 2330 2331 |
# File 'lib/aws-sdk-entityresolution/client.rb', line 2328 def tag_resource(params = {}, = {}) req = build_request(:tag_resource, params) req.send_request() end |
#untag_resource(params = {}) ⇒ Struct
Removes one or more tags from the specified Entity Resolution resource. In Entity Resolution, ‘SchemaMapping`, and `MatchingWorkflow` can be tagged.
2356 2357 2358 2359 |
# File 'lib/aws-sdk-entityresolution/client.rb', line 2356 def untag_resource(params = {}, = {}) req = build_request(:untag_resource, params) req.send_request() end |
#update_id_mapping_workflow(params = {}) ⇒ Types::UpdateIdMappingWorkflowOutput
Updates an existing ‘IdMappingWorkflow`. This method is identical to CreateIdMappingWorkflow, except it uses an HTTP `PUT` request instead of a `POST` request, and the `IdMappingWorkflow` must already exist for the method to succeed.
Incremental processing is not supported for ID mapping workflows.
2480 2481 2482 2483 |
# File 'lib/aws-sdk-entityresolution/client.rb', line 2480 def update_id_mapping_workflow(params = {}, = {}) req = build_request(:update_id_mapping_workflow, params) req.send_request() end |
#update_id_namespace(params = {}) ⇒ Types::UpdateIdNamespaceOutput
Updates an existing ID namespace.
2582 2583 2584 2585 |
# File 'lib/aws-sdk-entityresolution/client.rb', line 2582 def update_id_namespace(params = {}, = {}) req = build_request(:update_id_namespace, params) req.send_request() end |
#update_matching_workflow(params = {}) ⇒ Types::UpdateMatchingWorkflowOutput
Updates an existing matching workflow. The workflow must already exist for this operation to succeed.
For workflows where ‘resolutionType` is `ML_MATCHING` or `PROVIDER`, incremental processing is not supported.
2738 2739 2740 2741 |
# File 'lib/aws-sdk-entityresolution/client.rb', line 2738 def update_matching_workflow(params = {}, = {}) req = build_request(:update_matching_workflow, params) req.send_request() end |
#update_schema_mapping(params = {}) ⇒ Types::UpdateSchemaMappingOutput
Updates a schema mapping.
<note markdown=“1”> A schema is immutable if it is being used by a workflow. Therefore, you can’t update a schema mapping if it’s associated with a workflow.
</note>
2804 2805 2806 2807 |
# File 'lib/aws-sdk-entityresolution/client.rb', line 2804 def update_schema_mapping(params = {}, = {}) req = build_request(:update_schema_mapping, params) req.send_request() end |
#waiter_names ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
2833 2834 2835 |
# File 'lib/aws-sdk-entityresolution/client.rb', line 2833 def waiter_names [] end |