Class: Aws::EntityResolution::Client
- Inherits:
-
Seahorse::Client::Base
- Object
- Seahorse::Client::Base
- Aws::EntityResolution::Client
- Includes:
- ClientStubs
- Defined in:
- lib/aws-sdk-entityresolution/client.rb
Overview
An API client for EntityResolution. To construct a client, you need to configure a ‘:region` and `:credentials`.
client = Aws::EntityResolution::Client.new(
region: region_name,
credentials: credentials,
# ...
)
For details on configuring region and credentials see the [developer guide](/sdk-for-ruby/v3/developer-guide/setup-config.html).
See #initialize for a full list of supported configuration options.
Class Attribute Summary collapse
- .identifier ⇒ Object readonly private
API Operations collapse
-
#add_policy_statement(params = {}) ⇒ Types::AddPolicyStatementOutput
Adds a policy statement object.
-
#batch_delete_unique_id(params = {}) ⇒ Types::BatchDeleteUniqueIdOutput
Deletes multiple unique IDs in a matching workflow.
-
#create_id_mapping_workflow(params = {}) ⇒ Types::CreateIdMappingWorkflowOutput
Creates an ‘IdMappingWorkflow` object which stores the configuration of the data processing job to be run.
-
#create_id_namespace(params = {}) ⇒ Types::CreateIdNamespaceOutput
Creates an ID namespace object which will help customers provide metadata explaining their dataset and how to use it.
-
#create_matching_workflow(params = {}) ⇒ Types::CreateMatchingWorkflowOutput
Creates a matching workflow that defines the configuration for a data processing job.
-
#create_schema_mapping(params = {}) ⇒ Types::CreateSchemaMappingOutput
Creates a schema mapping, which defines the schema of the input customer records table.
-
#delete_id_mapping_workflow(params = {}) ⇒ Types::DeleteIdMappingWorkflowOutput
Deletes the ‘IdMappingWorkflow` with a given name.
-
#delete_id_namespace(params = {}) ⇒ Types::DeleteIdNamespaceOutput
Deletes the ‘IdNamespace` with a given name.
-
#delete_matching_workflow(params = {}) ⇒ Types::DeleteMatchingWorkflowOutput
Deletes the ‘MatchingWorkflow` with a given name.
-
#delete_policy_statement(params = {}) ⇒ Types::DeletePolicyStatementOutput
Deletes the policy statement.
-
#delete_schema_mapping(params = {}) ⇒ Types::DeleteSchemaMappingOutput
Deletes the ‘SchemaMapping` with a given name.
-
#generate_match_id(params = {}) ⇒ Types::GenerateMatchIdOutput
Generates or retrieves Match IDs for records using a rule-based matching workflow.
-
#get_id_mapping_job(params = {}) ⇒ Types::GetIdMappingJobOutput
Returns the status, metrics, and errors (if there are any) that are associated with a job.
-
#get_id_mapping_workflow(params = {}) ⇒ Types::GetIdMappingWorkflowOutput
Returns the ‘IdMappingWorkflow` with a given name, if it exists.
-
#get_id_namespace(params = {}) ⇒ Types::GetIdNamespaceOutput
Returns the ‘IdNamespace` with a given name, if it exists.
-
#get_match_id(params = {}) ⇒ Types::GetMatchIdOutput
Returns the corresponding Match ID of a customer record if the record has been processed in a rule-based matching workflow.
-
#get_matching_job(params = {}) ⇒ Types::GetMatchingJobOutput
Returns the status, metrics, and errors (if there are any) that are associated with a job.
-
#get_matching_workflow(params = {}) ⇒ Types::GetMatchingWorkflowOutput
Returns the ‘MatchingWorkflow` with a given name, if it exists.
-
#get_policy(params = {}) ⇒ Types::GetPolicyOutput
Returns the resource-based policy.
-
#get_provider_service(params = {}) ⇒ Types::GetProviderServiceOutput
Returns the ‘ProviderService` of a given name.
-
#get_schema_mapping(params = {}) ⇒ Types::GetSchemaMappingOutput
Returns the SchemaMapping of a given name.
-
#list_id_mapping_jobs(params = {}) ⇒ Types::ListIdMappingJobsOutput
Lists all ID mapping jobs for a given workflow.
-
#list_id_mapping_workflows(params = {}) ⇒ Types::ListIdMappingWorkflowsOutput
Returns a list of all the ‘IdMappingWorkflows` that have been created for an Amazon Web Services account.
-
#list_id_namespaces(params = {}) ⇒ Types::ListIdNamespacesOutput
Returns a list of all ID namespaces.
-
#list_matching_jobs(params = {}) ⇒ Types::ListMatchingJobsOutput
Lists all jobs for a given workflow.
-
#list_matching_workflows(params = {}) ⇒ Types::ListMatchingWorkflowsOutput
Returns a list of all the ‘MatchingWorkflows` that have been created for an Amazon Web Services account.
-
#list_provider_services(params = {}) ⇒ Types::ListProviderServicesOutput
Returns a list of all the ‘ProviderServices` that are available in this Amazon Web Services Region.
-
#list_schema_mappings(params = {}) ⇒ Types::ListSchemaMappingsOutput
Returns a list of all the ‘SchemaMappings` that have been created for an Amazon Web Services account.
-
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceOutput
Displays the tags associated with an Entity Resolution resource.
-
#put_policy(params = {}) ⇒ Types::PutPolicyOutput
Updates the resource-based policy.
-
#start_id_mapping_job(params = {}) ⇒ Types::StartIdMappingJobOutput
Starts the ‘IdMappingJob` of a workflow.
-
#start_matching_job(params = {}) ⇒ Types::StartMatchingJobOutput
Starts the ‘MatchingJob` of a workflow.
-
#tag_resource(params = {}) ⇒ Struct
Assigns one or more tags (key-value pairs) to the specified Entity Resolution resource.
-
#untag_resource(params = {}) ⇒ Struct
Removes one or more tags from the specified Entity Resolution resource.
-
#update_id_mapping_workflow(params = {}) ⇒ Types::UpdateIdMappingWorkflowOutput
Updates an existing ‘IdMappingWorkflow`.
-
#update_id_namespace(params = {}) ⇒ Types::UpdateIdNamespaceOutput
Updates an existing ID namespace.
-
#update_matching_workflow(params = {}) ⇒ Types::UpdateMatchingWorkflowOutput
Updates an existing matching workflow.
-
#update_schema_mapping(params = {}) ⇒ Types::UpdateSchemaMappingOutput
Updates a schema mapping.
Class Method Summary collapse
- .errors_module ⇒ Object private
Instance Method Summary collapse
- #build_request(operation_name, params = {}) ⇒ Object private
-
#initialize(options) ⇒ Client
constructor
A new instance of Client.
- #waiter_names ⇒ Object deprecated private Deprecated.
Constructor Details
#initialize(options) ⇒ Client
Returns a new instance of Client.
473 474 475 |
# File 'lib/aws-sdk-entityresolution/client.rb', line 473 def initialize(*args) super end |
Class Attribute Details
.identifier ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
2842 2843 2844 |
# File 'lib/aws-sdk-entityresolution/client.rb', line 2842 def identifier @identifier end |
Class Method Details
.errors_module ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
2845 2846 2847 |
# File 'lib/aws-sdk-entityresolution/client.rb', line 2845 def errors_module Errors end |
Instance Method Details
#add_policy_statement(params = {}) ⇒ Types::AddPolicyStatementOutput
Adds a policy statement object. To retrieve a list of existing policy statements, use the ‘GetPolicy` API.
539 540 541 542 |
# File 'lib/aws-sdk-entityresolution/client.rb', line 539 def add_policy_statement(params = {}, = {}) req = build_request(:add_policy_statement, params) req.send_request() end |
#batch_delete_unique_id(params = {}) ⇒ Types::BatchDeleteUniqueIdOutput
Deletes multiple unique IDs in a matching workflow.
585 586 587 588 |
# File 'lib/aws-sdk-entityresolution/client.rb', line 585 def batch_delete_unique_id(params = {}, = {}) req = build_request(:batch_delete_unique_id, params) req.send_request() end |
#build_request(operation_name, params = {}) ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
2815 2816 2817 2818 2819 2820 2821 2822 2823 2824 2825 2826 2827 2828 2829 2830 2831 |
# File 'lib/aws-sdk-entityresolution/client.rb', line 2815 def build_request(operation_name, params = {}) handlers = @handlers.for(operation_name) tracer = config.telemetry_provider.tracer_provider.tracer( Aws::Telemetry.module_to_tracer_name('Aws::EntityResolution') ) context = Seahorse::Client::RequestContext.new( operation_name: operation_name, operation: config.api.operation(operation_name), client: self, params: params, config: config, tracer: tracer ) context[:gem_name] = 'aws-sdk-entityresolution' context[:gem_version] = '1.46.0' Seahorse::Client::Request.new(handlers, context) end |
#create_id_mapping_workflow(params = {}) ⇒ Types::CreateIdMappingWorkflowOutput
Creates an ‘IdMappingWorkflow` object which stores the configuration of the data processing job to be run. Each `IdMappingWorkflow` must have a unique workflow name. To modify an existing workflow, use the UpdateIdMappingWorkflow API.
Incremental processing is not supported for ID mapping workflows.
716 717 718 719 |
# File 'lib/aws-sdk-entityresolution/client.rb', line 716 def create_id_mapping_workflow(params = {}, = {}) req = build_request(:create_id_mapping_workflow, params) req.send_request() end |
#create_id_namespace(params = {}) ⇒ Types::CreateIdNamespaceOutput
Creates an ID namespace object which will help customers provide metadata explaining their dataset and how to use it. Each ID namespace must have a unique name. To modify an existing ID namespace, use the UpdateIdNamespace API.
840 841 842 843 |
# File 'lib/aws-sdk-entityresolution/client.rb', line 840 def create_id_namespace(params = {}, = {}) req = build_request(:create_id_namespace, params) req.send_request() end |
#create_matching_workflow(params = {}) ⇒ Types::CreateMatchingWorkflowOutput
Creates a matching workflow that defines the configuration for a data processing job. The workflow name must be unique. To modify an existing workflow, use ‘UpdateMatchingWorkflow`.
For workflows where ‘resolutionType` is `ML_MATCHING` or `PROVIDER`, incremental processing is not supported.
1006 1007 1008 1009 |
# File 'lib/aws-sdk-entityresolution/client.rb', line 1006 def create_matching_workflow(params = {}, = {}) req = build_request(:create_matching_workflow, params) req.send_request() end |
#create_schema_mapping(params = {}) ⇒ Types::CreateSchemaMappingOutput
Creates a schema mapping, which defines the schema of the input customer records table. The ‘SchemaMapping` also provides Entity Resolution with some metadata about the table, such as the attribute types of the columns and which columns to match on.
1075 1076 1077 1078 |
# File 'lib/aws-sdk-entityresolution/client.rb', line 1075 def create_schema_mapping(params = {}, = {}) req = build_request(:create_schema_mapping, params) req.send_request() end |
#delete_id_mapping_workflow(params = {}) ⇒ Types::DeleteIdMappingWorkflowOutput
Deletes the ‘IdMappingWorkflow` with a given name. This operation will succeed even if a workflow with the given name does not exist.
1104 1105 1106 1107 |
# File 'lib/aws-sdk-entityresolution/client.rb', line 1104 def delete_id_mapping_workflow(params = {}, = {}) req = build_request(:delete_id_mapping_workflow, params) req.send_request() end |
#delete_id_namespace(params = {}) ⇒ Types::DeleteIdNamespaceOutput
Deletes the ‘IdNamespace` with a given name.
1132 1133 1134 1135 |
# File 'lib/aws-sdk-entityresolution/client.rb', line 1132 def delete_id_namespace(params = {}, = {}) req = build_request(:delete_id_namespace, params) req.send_request() end |
#delete_matching_workflow(params = {}) ⇒ Types::DeleteMatchingWorkflowOutput
Deletes the ‘MatchingWorkflow` with a given name. This operation will succeed even if a workflow with the given name does not exist.
1161 1162 1163 1164 |
# File 'lib/aws-sdk-entityresolution/client.rb', line 1161 def delete_matching_workflow(params = {}, = {}) req = build_request(:delete_matching_workflow, params) req.send_request() end |
#delete_policy_statement(params = {}) ⇒ Types::DeletePolicyStatementOutput
Deletes the policy statement.
1198 1199 1200 1201 |
# File 'lib/aws-sdk-entityresolution/client.rb', line 1198 def delete_policy_statement(params = {}, = {}) req = build_request(:delete_policy_statement, params) req.send_request() end |
#delete_schema_mapping(params = {}) ⇒ Types::DeleteSchemaMappingOutput
Deletes the ‘SchemaMapping` with a given name. This operation will succeed even if a schema with the given name does not exist. This operation will fail if there is a `MatchingWorkflow` object that references the `SchemaMapping` in the workflow’s ‘InputSourceConfig`.
1229 1230 1231 1232 |
# File 'lib/aws-sdk-entityresolution/client.rb', line 1229 def delete_schema_mapping(params = {}, = {}) req = build_request(:delete_schema_mapping, params) req.send_request() end |
#generate_match_id(params = {}) ⇒ Types::GenerateMatchIdOutput
Generates or retrieves Match IDs for records using a rule-based matching workflow. When you call this operation, it processes your records against the workflow’s matching rules to identify potential matches. For existing records, it retrieves their Match IDs and associated rules. For records without matches, it generates new Match IDs. The operation saves results to Amazon S3.
The processing type (‘processingType`) you choose affects both the accuracy and response time of the operation. Additional charges apply for each API call, whether made through the Entity Resolution console or directly via the API. The rule-based matching workflow must exist and be active before calling this operation.
1312 1313 1314 1315 |
# File 'lib/aws-sdk-entityresolution/client.rb', line 1312 def generate_match_id(params = {}, = {}) req = build_request(:generate_match_id, params) req.send_request() end |
#get_id_mapping_job(params = {}) ⇒ Types::GetIdMappingJobOutput
Returns the status, metrics, and errors (if there are any) that are associated with a job.
1376 1377 1378 1379 |
# File 'lib/aws-sdk-entityresolution/client.rb', line 1376 def get_id_mapping_job(params = {}, = {}) req = build_request(:get_id_mapping_job, params) req.send_request() end |
#get_id_mapping_workflow(params = {}) ⇒ Types::GetIdMappingWorkflowOutput
Returns the ‘IdMappingWorkflow` with a given name, if it exists.
1439 1440 1441 1442 |
# File 'lib/aws-sdk-entityresolution/client.rb', line 1439 def get_id_mapping_workflow(params = {}, = {}) req = build_request(:get_id_mapping_workflow, params) req.send_request() end |
#get_id_namespace(params = {}) ⇒ Types::GetIdNamespaceOutput
Returns the ‘IdNamespace` with a given name, if it exists.
1499 1500 1501 1502 |
# File 'lib/aws-sdk-entityresolution/client.rb', line 1499 def get_id_namespace(params = {}, = {}) req = build_request(:get_id_namespace, params) req.send_request() end |
#get_match_id(params = {}) ⇒ Types::GetMatchIdOutput
Returns the corresponding Match ID of a customer record if the record has been processed in a rule-based matching workflow.
You can call this API as a dry run of an incremental load on the rule-based matching workflow.
1546 1547 1548 1549 |
# File 'lib/aws-sdk-entityresolution/client.rb', line 1546 def get_match_id(params = {}, = {}) req = build_request(:get_match_id, params) req.send_request() end |
#get_matching_job(params = {}) ⇒ Types::GetMatchingJobOutput
Returns the status, metrics, and errors (if there are any) that are associated with a job.
1598 1599 1600 1601 |
# File 'lib/aws-sdk-entityresolution/client.rb', line 1598 def get_matching_job(params = {}, = {}) req = build_request(:get_matching_job, params) req.send_request() end |
#get_matching_workflow(params = {}) ⇒ Types::GetMatchingWorkflowOutput
Returns the ‘MatchingWorkflow` with a given name, if it exists.
1670 1671 1672 1673 |
# File 'lib/aws-sdk-entityresolution/client.rb', line 1670 def get_matching_workflow(params = {}, = {}) req = build_request(:get_matching_workflow, params) req.send_request() end |
#get_policy(params = {}) ⇒ Types::GetPolicyOutput
Returns the resource-based policy.
1703 1704 1705 1706 |
# File 'lib/aws-sdk-entityresolution/client.rb', line 1703 def get_policy(params = {}, = {}) req = build_request(:get_policy, params) req.send_request() end |
#get_provider_service(params = {}) ⇒ Types::GetProviderServiceOutput
Returns the ‘ProviderService` of a given name.
1770 1771 1772 1773 |
# File 'lib/aws-sdk-entityresolution/client.rb', line 1770 def get_provider_service(params = {}, = {}) req = build_request(:get_provider_service, params) req.send_request() end |
#get_schema_mapping(params = {}) ⇒ Types::GetSchemaMappingOutput
Returns the SchemaMapping of a given name.
1819 1820 1821 1822 |
# File 'lib/aws-sdk-entityresolution/client.rb', line 1819 def get_schema_mapping(params = {}, = {}) req = build_request(:get_schema_mapping, params) req.send_request() end |
#list_id_mapping_jobs(params = {}) ⇒ Types::ListIdMappingJobsOutput
Lists all ID mapping jobs for a given workflow.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1863 1864 1865 1866 |
# File 'lib/aws-sdk-entityresolution/client.rb', line 1863 def list_id_mapping_jobs(params = {}, = {}) req = build_request(:list_id_mapping_jobs, params) req.send_request() end |
#list_id_mapping_workflows(params = {}) ⇒ Types::ListIdMappingWorkflowsOutput
Returns a list of all the ‘IdMappingWorkflows` that have been created for an Amazon Web Services account.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1904 1905 1906 1907 |
# File 'lib/aws-sdk-entityresolution/client.rb', line 1904 def list_id_mapping_workflows(params = {}, = {}) req = build_request(:list_id_mapping_workflows, params) req.send_request() end |
#list_id_namespaces(params = {}) ⇒ Types::ListIdNamespacesOutput
Returns a list of all ID namespaces.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1948 1949 1950 1951 |
# File 'lib/aws-sdk-entityresolution/client.rb', line 1948 def list_id_namespaces(params = {}, = {}) req = build_request(:list_id_namespaces, params) req.send_request() end |
#list_matching_jobs(params = {}) ⇒ Types::ListMatchingJobsOutput
Lists all jobs for a given workflow.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1992 1993 1994 1995 |
# File 'lib/aws-sdk-entityresolution/client.rb', line 1992 def list_matching_jobs(params = {}, = {}) req = build_request(:list_matching_jobs, params) req.send_request() end |
#list_matching_workflows(params = {}) ⇒ Types::ListMatchingWorkflowsOutput
Returns a list of all the ‘MatchingWorkflows` that have been created for an Amazon Web Services account.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
2034 2035 2036 2037 |
# File 'lib/aws-sdk-entityresolution/client.rb', line 2034 def list_matching_workflows(params = {}, = {}) req = build_request(:list_matching_workflows, params) req.send_request() end |
#list_provider_services(params = {}) ⇒ Types::ListProviderServicesOutput
Returns a list of all the ‘ProviderServices` that are available in this Amazon Web Services Region.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
2080 2081 2082 2083 |
# File 'lib/aws-sdk-entityresolution/client.rb', line 2080 def list_provider_services(params = {}, = {}) req = build_request(:list_provider_services, params) req.send_request() end |
#list_schema_mappings(params = {}) ⇒ Types::ListSchemaMappingsOutput
Returns a list of all the ‘SchemaMappings` that have been created for an Amazon Web Services account.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
2122 2123 2124 2125 |
# File 'lib/aws-sdk-entityresolution/client.rb', line 2122 def list_schema_mappings(params = {}, = {}) req = build_request(:list_schema_mappings, params) req.send_request() end |
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceOutput
Displays the tags associated with an Entity Resolution resource. In Entity Resolution, ‘SchemaMapping`, and `MatchingWorkflow` can be tagged.
2153 2154 2155 2156 |
# File 'lib/aws-sdk-entityresolution/client.rb', line 2153 def (params = {}, = {}) req = build_request(:list_tags_for_resource, params) req.send_request() end |
#put_policy(params = {}) ⇒ Types::PutPolicyOutput
Updates the resource-based policy.
2199 2200 2201 2202 |
# File 'lib/aws-sdk-entityresolution/client.rb', line 2199 def put_policy(params = {}, = {}) req = build_request(:put_policy, params) req.send_request() end |
#start_id_mapping_job(params = {}) ⇒ Types::StartIdMappingJobOutput
Starts the ‘IdMappingJob` of a workflow. The workflow must have previously been created using the `CreateIdMappingWorkflow` endpoint.
2262 2263 2264 2265 |
# File 'lib/aws-sdk-entityresolution/client.rb', line 2262 def start_id_mapping_job(params = {}, = {}) req = build_request(:start_id_mapping_job, params) req.send_request() end |
#start_matching_job(params = {}) ⇒ Types::StartMatchingJobOutput
Starts the ‘MatchingJob` of a workflow. The workflow must have previously been created using the `CreateMatchingWorkflow` endpoint.
2291 2292 2293 2294 |
# File 'lib/aws-sdk-entityresolution/client.rb', line 2291 def start_matching_job(params = {}, = {}) req = build_request(:start_matching_job, params) req.send_request() end |
#tag_resource(params = {}) ⇒ Struct
Assigns one or more tags (key-value pairs) to the specified Entity Resolution resource. Tags can help you organize and categorize your resources. You can also use them to scope user permissions by granting a user permission to access or change only resources with certain tag values. In Entity Resolution, ‘SchemaMapping` and `MatchingWorkflow` can be tagged. Tags don’t have any semantic meaning to Amazon Web Services and are interpreted strictly as strings of characters. You can use the ‘TagResource` action with a resource that already has tags. If you specify a new tag key, this tag is appended to the list of tags associated with the resource. If you specify a tag key that is already associated with the resource, the new tag value that you specify replaces the previous value for that tag.
2330 2331 2332 2333 |
# File 'lib/aws-sdk-entityresolution/client.rb', line 2330 def tag_resource(params = {}, = {}) req = build_request(:tag_resource, params) req.send_request() end |
#untag_resource(params = {}) ⇒ Struct
Removes one or more tags from the specified Entity Resolution resource. In Entity Resolution, ‘SchemaMapping`, and `MatchingWorkflow` can be tagged.
2358 2359 2360 2361 |
# File 'lib/aws-sdk-entityresolution/client.rb', line 2358 def untag_resource(params = {}, = {}) req = build_request(:untag_resource, params) req.send_request() end |
#update_id_mapping_workflow(params = {}) ⇒ Types::UpdateIdMappingWorkflowOutput
Updates an existing ‘IdMappingWorkflow`. This method is identical to CreateIdMappingWorkflow, except it uses an HTTP `PUT` request instead of a `POST` request, and the `IdMappingWorkflow` must already exist for the method to succeed.
Incremental processing is not supported for ID mapping workflows.
2482 2483 2484 2485 |
# File 'lib/aws-sdk-entityresolution/client.rb', line 2482 def update_id_mapping_workflow(params = {}, = {}) req = build_request(:update_id_mapping_workflow, params) req.send_request() end |
#update_id_namespace(params = {}) ⇒ Types::UpdateIdNamespaceOutput
Updates an existing ID namespace.
2584 2585 2586 2587 |
# File 'lib/aws-sdk-entityresolution/client.rb', line 2584 def update_id_namespace(params = {}, = {}) req = build_request(:update_id_namespace, params) req.send_request() end |
#update_matching_workflow(params = {}) ⇒ Types::UpdateMatchingWorkflowOutput
Updates an existing matching workflow. The workflow must already exist for this operation to succeed.
For workflows where ‘resolutionType` is `ML_MATCHING` or `PROVIDER`, incremental processing is not supported.
2740 2741 2742 2743 |
# File 'lib/aws-sdk-entityresolution/client.rb', line 2740 def update_matching_workflow(params = {}, = {}) req = build_request(:update_matching_workflow, params) req.send_request() end |
#update_schema_mapping(params = {}) ⇒ Types::UpdateSchemaMappingOutput
Updates a schema mapping.
<note markdown=“1”> A schema is immutable if it is being used by a workflow. Therefore, you can’t update a schema mapping if it’s associated with a workflow.
</note>
2806 2807 2808 2809 |
# File 'lib/aws-sdk-entityresolution/client.rb', line 2806 def update_schema_mapping(params = {}, = {}) req = build_request(:update_schema_mapping, params) req.send_request() end |
#waiter_names ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
2835 2836 2837 |
# File 'lib/aws-sdk-entityresolution/client.rb', line 2835 def waiter_names [] end |