Class: Aws::EntityResolution::Types::CreateIdNamespaceInput
- Inherits:
-
Struct
- Object
- Struct
- Aws::EntityResolution::Types::CreateIdNamespaceInput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-entityresolution/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#description ⇒ String
The description of the ID namespace.
-
#id_mapping_workflow_properties ⇒ Array<Types::IdNamespaceIdMappingWorkflowProperties>
Determines the properties of
IdMappingWorflowwhere thisIdNamespacecan be used as aSourceor aTarget. -
#id_namespace_name ⇒ String
The name of the ID namespace.
-
#input_source_config ⇒ Array<Types::IdNamespaceInputSource>
A list of
InputSourceobjects, which have the fieldsInputSourceARNandSchemaName. -
#role_arn ⇒ String
The Amazon Resource Name (ARN) of the IAM role.
-
#tags ⇒ Hash<String,String>
The tags used to organize, track, or control access for this resource.
-
#type ⇒ String
The type of ID namespace.
Instance Attribute Details
#description ⇒ String
The description of the ID namespace.
301 302 303 304 305 306 307 308 309 310 311 |
# File 'lib/aws-sdk-entityresolution/types.rb', line 301 class CreateIdNamespaceInput < Struct.new( :id_namespace_name, :description, :input_source_config, :id_mapping_workflow_properties, :type, :role_arn, :tags) SENSITIVE = [] include Aws::Structure end |
#id_mapping_workflow_properties ⇒ Array<Types::IdNamespaceIdMappingWorkflowProperties>
Determines the properties of IdMappingWorflow where this IdNamespace can be used as a Source or a Target.
301 302 303 304 305 306 307 308 309 310 311 |
# File 'lib/aws-sdk-entityresolution/types.rb', line 301 class CreateIdNamespaceInput < Struct.new( :id_namespace_name, :description, :input_source_config, :id_mapping_workflow_properties, :type, :role_arn, :tags) SENSITIVE = [] include Aws::Structure end |
#id_namespace_name ⇒ String
The name of the ID namespace.
301 302 303 304 305 306 307 308 309 310 311 |
# File 'lib/aws-sdk-entityresolution/types.rb', line 301 class CreateIdNamespaceInput < Struct.new( :id_namespace_name, :description, :input_source_config, :id_mapping_workflow_properties, :type, :role_arn, :tags) SENSITIVE = [] include Aws::Structure end |
#input_source_config ⇒ Array<Types::IdNamespaceInputSource>
A list of InputSource objects, which have the fields InputSourceARN and SchemaName.
301 302 303 304 305 306 307 308 309 310 311 |
# File 'lib/aws-sdk-entityresolution/types.rb', line 301 class CreateIdNamespaceInput < Struct.new( :id_namespace_name, :description, :input_source_config, :id_mapping_workflow_properties, :type, :role_arn, :tags) SENSITIVE = [] include Aws::Structure end |
#role_arn ⇒ String
The Amazon Resource Name (ARN) of the IAM role. Entity Resolution assumes this role to access the resources defined in this IdNamespace on your behalf as part of the workflow run.
301 302 303 304 305 306 307 308 309 310 311 |
# File 'lib/aws-sdk-entityresolution/types.rb', line 301 class CreateIdNamespaceInput < Struct.new( :id_namespace_name, :description, :input_source_config, :id_mapping_workflow_properties, :type, :role_arn, :tags) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Hash<String,String>
The tags used to organize, track, or control access for this resource.
301 302 303 304 305 306 307 308 309 310 311 |
# File 'lib/aws-sdk-entityresolution/types.rb', line 301 class CreateIdNamespaceInput < Struct.new( :id_namespace_name, :description, :input_source_config, :id_mapping_workflow_properties, :type, :role_arn, :tags) SENSITIVE = [] include Aws::Structure end |
#type ⇒ String
The type of ID namespace. There are two types: SOURCE and TARGET.
The SOURCE contains configurations for sourceId data that will be processed in an ID mapping workflow.
The TARGET contains a configuration of targetId to which all sourceIds will resolve to.
301 302 303 304 305 306 307 308 309 310 311 |
# File 'lib/aws-sdk-entityresolution/types.rb', line 301 class CreateIdNamespaceInput < Struct.new( :id_namespace_name, :description, :input_source_config, :id_mapping_workflow_properties, :type, :role_arn, :tags) SENSITIVE = [] include Aws::Structure end |