Class: Aws::EntityResolution::Types::CreateMatchingWorkflowInput
- Inherits:
-
Struct
- Object
- Struct
- Aws::EntityResolution::Types::CreateMatchingWorkflowInput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-entityresolution/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#description ⇒ String
A description of the workflow.
-
#incremental_run_config ⇒ Types::IncrementalRunConfig
Optional.
-
#input_source_config ⇒ Array<Types::InputSource>
A list of
InputSourceobjects, which have the fieldsInputSourceARNandSchemaName. -
#output_source_config ⇒ Array<Types::OutputSource>
A list of
OutputSourceobjects, each of which contains fieldsoutputS3Path,applyNormalization,KMSArn, andoutput. -
#resolution_techniques ⇒ Types::ResolutionTechniques
An object which defines the
resolutionTypeand theruleBasedProperties. -
#role_arn ⇒ String
The Amazon Resource Name (ARN) of the IAM role.
-
#tags ⇒ Hash<String,String>
The tags used to organize, track, or control access for this resource.
-
#workflow_name ⇒ String
The name of the workflow.
Instance Attribute Details
#description ⇒ String
A description of the workflow.
428 429 430 431 432 433 434 435 436 437 438 439 |
# File 'lib/aws-sdk-entityresolution/types.rb', line 428 class CreateMatchingWorkflowInput < Struct.new( :workflow_name, :description, :input_source_config, :output_source_config, :resolution_techniques, :incremental_run_config, :role_arn, :tags) SENSITIVE = [] include Aws::Structure end |
#incremental_run_config ⇒ Types::IncrementalRunConfig
Optional. An object that defines the incremental run type. This object contains only the incrementalRunType field, which appears as “Automatic” in the console.
For workflows where resolutionType is ML_MATCHING, incremental processing is not supported.
428 429 430 431 432 433 434 435 436 437 438 439 |
# File 'lib/aws-sdk-entityresolution/types.rb', line 428 class CreateMatchingWorkflowInput < Struct.new( :workflow_name, :description, :input_source_config, :output_source_config, :resolution_techniques, :incremental_run_config, :role_arn, :tags) SENSITIVE = [] include Aws::Structure end |
#input_source_config ⇒ Array<Types::InputSource>
A list of InputSource objects, which have the fields InputSourceARN and SchemaName.
428 429 430 431 432 433 434 435 436 437 438 439 |
# File 'lib/aws-sdk-entityresolution/types.rb', line 428 class CreateMatchingWorkflowInput < Struct.new( :workflow_name, :description, :input_source_config, :output_source_config, :resolution_techniques, :incremental_run_config, :role_arn, :tags) SENSITIVE = [] include Aws::Structure end |
#output_source_config ⇒ Array<Types::OutputSource>
A list of OutputSource objects, each of which contains fields outputS3Path, applyNormalization, KMSArn, and output.
428 429 430 431 432 433 434 435 436 437 438 439 |
# File 'lib/aws-sdk-entityresolution/types.rb', line 428 class CreateMatchingWorkflowInput < Struct.new( :workflow_name, :description, :input_source_config, :output_source_config, :resolution_techniques, :incremental_run_config, :role_arn, :tags) SENSITIVE = [] include Aws::Structure end |
#resolution_techniques ⇒ Types::ResolutionTechniques
An object which defines the resolutionType and the ruleBasedProperties.
428 429 430 431 432 433 434 435 436 437 438 439 |
# File 'lib/aws-sdk-entityresolution/types.rb', line 428 class CreateMatchingWorkflowInput < Struct.new( :workflow_name, :description, :input_source_config, :output_source_config, :resolution_techniques, :incremental_run_config, :role_arn, :tags) SENSITIVE = [] include Aws::Structure end |
#role_arn ⇒ String
The Amazon Resource Name (ARN) of the IAM role. Entity Resolution assumes this role to create resources on your behalf as part of workflow execution.
428 429 430 431 432 433 434 435 436 437 438 439 |
# File 'lib/aws-sdk-entityresolution/types.rb', line 428 class CreateMatchingWorkflowInput < Struct.new( :workflow_name, :description, :input_source_config, :output_source_config, :resolution_techniques, :incremental_run_config, :role_arn, :tags) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Hash<String,String>
The tags used to organize, track, or control access for this resource.
428 429 430 431 432 433 434 435 436 437 438 439 |
# File 'lib/aws-sdk-entityresolution/types.rb', line 428 class CreateMatchingWorkflowInput < Struct.new( :workflow_name, :description, :input_source_config, :output_source_config, :resolution_techniques, :incremental_run_config, :role_arn, :tags) SENSITIVE = [] include Aws::Structure end |
#workflow_name ⇒ String
The name of the workflow. There can’t be multiple MatchingWorkflows with the same name.
428 429 430 431 432 433 434 435 436 437 438 439 |
# File 'lib/aws-sdk-entityresolution/types.rb', line 428 class CreateMatchingWorkflowInput < Struct.new( :workflow_name, :description, :input_source_config, :output_source_config, :resolution_techniques, :incremental_run_config, :role_arn, :tags) SENSITIVE = [] include Aws::Structure end |