Class: Aws::EntityResolution::Types::GetIdMappingWorkflowOutput
- Inherits:
-
Struct
- Object
- Struct
- Aws::EntityResolution::Types::GetIdMappingWorkflowOutput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-entityresolution/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#created_at ⇒ Time
The timestamp of when the workflow was created.
-
#description ⇒ String
A description of the workflow.
-
#id_mapping_techniques ⇒ Types::IdMappingTechniques
An object which defines the ID mapping technique and any additional configurations.
-
#input_source_config ⇒ Array<Types::IdMappingWorkflowInputSource>
A list of
InputSourceobjects, which have the fieldsInputSourceARNandSchemaName. -
#output_source_config ⇒ Array<Types::IdMappingWorkflowOutputSource>
A list of
OutputSourceobjects, each of which contains fieldsoutputS3PathandKMSArn. -
#role_arn ⇒ String
The Amazon Resource Name (ARN) of the IAM role.
-
#tags ⇒ Hash<String,String>
The tags used to organize, track, or control access for this resource.
-
#updated_at ⇒ Time
The timestamp of when the workflow was last updated.
-
#workflow_arn ⇒ String
The ARN (Amazon Resource Name) that Entity Resolution generated for the
IdMappingWorkflow. -
#workflow_name ⇒ String
The name of the workflow.
Instance Attribute Details
#created_at ⇒ Time
The timestamp of when the workflow was created.
966 967 968 969 970 971 972 973 974 975 976 977 978 979 |
# File 'lib/aws-sdk-entityresolution/types.rb', line 966 class GetIdMappingWorkflowOutput < Struct.new( :workflow_name, :workflow_arn, :description, :input_source_config, :output_source_config, :id_mapping_techniques, :created_at, :updated_at, :role_arn, :tags) SENSITIVE = [] include Aws::Structure end |
#description ⇒ String
A description of the workflow.
966 967 968 969 970 971 972 973 974 975 976 977 978 979 |
# File 'lib/aws-sdk-entityresolution/types.rb', line 966 class GetIdMappingWorkflowOutput < Struct.new( :workflow_name, :workflow_arn, :description, :input_source_config, :output_source_config, :id_mapping_techniques, :created_at, :updated_at, :role_arn, :tags) SENSITIVE = [] include Aws::Structure end |
#id_mapping_techniques ⇒ Types::IdMappingTechniques
An object which defines the ID mapping technique and any additional configurations.
966 967 968 969 970 971 972 973 974 975 976 977 978 979 |
# File 'lib/aws-sdk-entityresolution/types.rb', line 966 class GetIdMappingWorkflowOutput < Struct.new( :workflow_name, :workflow_arn, :description, :input_source_config, :output_source_config, :id_mapping_techniques, :created_at, :updated_at, :role_arn, :tags) SENSITIVE = [] include Aws::Structure end |
#input_source_config ⇒ Array<Types::IdMappingWorkflowInputSource>
A list of InputSource objects, which have the fields
InputSourceARN and SchemaName.
966 967 968 969 970 971 972 973 974 975 976 977 978 979 |
# File 'lib/aws-sdk-entityresolution/types.rb', line 966 class GetIdMappingWorkflowOutput < Struct.new( :workflow_name, :workflow_arn, :description, :input_source_config, :output_source_config, :id_mapping_techniques, :created_at, :updated_at, :role_arn, :tags) SENSITIVE = [] include Aws::Structure end |
#output_source_config ⇒ Array<Types::IdMappingWorkflowOutputSource>
A list of OutputSource objects, each of which contains fields
outputS3Path and KMSArn.
966 967 968 969 970 971 972 973 974 975 976 977 978 979 |
# File 'lib/aws-sdk-entityresolution/types.rb', line 966 class GetIdMappingWorkflowOutput < Struct.new( :workflow_name, :workflow_arn, :description, :input_source_config, :output_source_config, :id_mapping_techniques, :created_at, :updated_at, :role_arn, :tags) SENSITIVE = [] include Aws::Structure end |
#role_arn ⇒ String
The Amazon Resource Name (ARN) of the IAM role. Entity Resolution assumes this role to access Amazon Web Services resources on your behalf.
966 967 968 969 970 971 972 973 974 975 976 977 978 979 |
# File 'lib/aws-sdk-entityresolution/types.rb', line 966 class GetIdMappingWorkflowOutput < Struct.new( :workflow_name, :workflow_arn, :description, :input_source_config, :output_source_config, :id_mapping_techniques, :created_at, :updated_at, :role_arn, :tags) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Hash<String,String>
The tags used to organize, track, or control access for this resource.
966 967 968 969 970 971 972 973 974 975 976 977 978 979 |
# File 'lib/aws-sdk-entityresolution/types.rb', line 966 class GetIdMappingWorkflowOutput < Struct.new( :workflow_name, :workflow_arn, :description, :input_source_config, :output_source_config, :id_mapping_techniques, :created_at, :updated_at, :role_arn, :tags) SENSITIVE = [] include Aws::Structure end |
#updated_at ⇒ Time
The timestamp of when the workflow was last updated.
966 967 968 969 970 971 972 973 974 975 976 977 978 979 |
# File 'lib/aws-sdk-entityresolution/types.rb', line 966 class GetIdMappingWorkflowOutput < Struct.new( :workflow_name, :workflow_arn, :description, :input_source_config, :output_source_config, :id_mapping_techniques, :created_at, :updated_at, :role_arn, :tags) SENSITIVE = [] include Aws::Structure end |
#workflow_arn ⇒ String
The ARN (Amazon Resource Name) that Entity Resolution generated for
the IdMappingWorkflow .
966 967 968 969 970 971 972 973 974 975 976 977 978 979 |
# File 'lib/aws-sdk-entityresolution/types.rb', line 966 class GetIdMappingWorkflowOutput < Struct.new( :workflow_name, :workflow_arn, :description, :input_source_config, :output_source_config, :id_mapping_techniques, :created_at, :updated_at, :role_arn, :tags) SENSITIVE = [] include Aws::Structure end |
#workflow_name ⇒ String
The name of the workflow.
966 967 968 969 970 971 972 973 974 975 976 977 978 979 |
# File 'lib/aws-sdk-entityresolution/types.rb', line 966 class GetIdMappingWorkflowOutput < Struct.new( :workflow_name, :workflow_arn, :description, :input_source_config, :output_source_config, :id_mapping_techniques, :created_at, :updated_at, :role_arn, :tags) SENSITIVE = [] include Aws::Structure end |