Class: Aws::EntityResolution::Types::GetMatchingWorkflowOutput
- Inherits:
-
Struct
- Object
- Struct
- Aws::EntityResolution::Types::GetMatchingWorkflowOutput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-entityresolution/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#created_at ⇒ Time
The timestamp of when the workflow was created.
-
#description ⇒ String
A description of the workflow.
-
#incremental_run_config ⇒ Types::IncrementalRunConfig
An object which defines an incremental run type and has only
incrementalRunTypeas a field. -
#input_source_config ⇒ Array<Types::InputSource>
A list of
InputSourceobjects, which have the fieldsInputSourceARNandSchemaName. -
#output_source_config ⇒ Array<Types::OutputSource>
A list of
OutputSourceobjects, each of which contains fieldsoutputS3Path,applyNormalization,KMSArn, andoutput. -
#resolution_techniques ⇒ Types::ResolutionTechniques
An object which defines the
resolutionTypeand theruleBasedProperties. -
#role_arn ⇒ String
The Amazon Resource Name (ARN) of the IAM role.
-
#tags ⇒ Hash<String,String>
The tags used to organize, track, or control access for this resource.
-
#updated_at ⇒ Time
The timestamp of when the workflow was last updated.
-
#workflow_arn ⇒ String
The ARN (Amazon Resource Name) that Entity Resolution generated for the
MatchingWorkflow. -
#workflow_name ⇒ String
The name of the workflow.
Instance Attribute Details
#created_at ⇒ Time
The timestamp of when the workflow was created.
1231 1232 1233 1234 1235 1236 1237 1238 1239 1240 1241 1242 1243 1244 1245 |
# File 'lib/aws-sdk-entityresolution/types.rb', line 1231 class GetMatchingWorkflowOutput < Struct.new( :workflow_name, :workflow_arn, :description, :input_source_config, :output_source_config, :resolution_techniques, :created_at, :updated_at, :incremental_run_config, :role_arn, :tags) SENSITIVE = [] include Aws::Structure end |
#description ⇒ String
A description of the workflow.
1231 1232 1233 1234 1235 1236 1237 1238 1239 1240 1241 1242 1243 1244 1245 |
# File 'lib/aws-sdk-entityresolution/types.rb', line 1231 class GetMatchingWorkflowOutput < Struct.new( :workflow_name, :workflow_arn, :description, :input_source_config, :output_source_config, :resolution_techniques, :created_at, :updated_at, :incremental_run_config, :role_arn, :tags) SENSITIVE = [] include Aws::Structure end |
#incremental_run_config ⇒ Types::IncrementalRunConfig
An object which defines an incremental run type and has only incrementalRunType as a field.
1231 1232 1233 1234 1235 1236 1237 1238 1239 1240 1241 1242 1243 1244 1245 |
# File 'lib/aws-sdk-entityresolution/types.rb', line 1231 class GetMatchingWorkflowOutput < Struct.new( :workflow_name, :workflow_arn, :description, :input_source_config, :output_source_config, :resolution_techniques, :created_at, :updated_at, :incremental_run_config, :role_arn, :tags) SENSITIVE = [] include Aws::Structure end |
#input_source_config ⇒ Array<Types::InputSource>
A list of InputSource objects, which have the fields InputSourceARN and SchemaName.
1231 1232 1233 1234 1235 1236 1237 1238 1239 1240 1241 1242 1243 1244 1245 |
# File 'lib/aws-sdk-entityresolution/types.rb', line 1231 class GetMatchingWorkflowOutput < Struct.new( :workflow_name, :workflow_arn, :description, :input_source_config, :output_source_config, :resolution_techniques, :created_at, :updated_at, :incremental_run_config, :role_arn, :tags) SENSITIVE = [] include Aws::Structure end |
#output_source_config ⇒ Array<Types::OutputSource>
A list of OutputSource objects, each of which contains fields outputS3Path, applyNormalization, KMSArn, and output.
1231 1232 1233 1234 1235 1236 1237 1238 1239 1240 1241 1242 1243 1244 1245 |
# File 'lib/aws-sdk-entityresolution/types.rb', line 1231 class GetMatchingWorkflowOutput < Struct.new( :workflow_name, :workflow_arn, :description, :input_source_config, :output_source_config, :resolution_techniques, :created_at, :updated_at, :incremental_run_config, :role_arn, :tags) SENSITIVE = [] include Aws::Structure end |
#resolution_techniques ⇒ Types::ResolutionTechniques
An object which defines the resolutionType and the ruleBasedProperties.
1231 1232 1233 1234 1235 1236 1237 1238 1239 1240 1241 1242 1243 1244 1245 |
# File 'lib/aws-sdk-entityresolution/types.rb', line 1231 class GetMatchingWorkflowOutput < Struct.new( :workflow_name, :workflow_arn, :description, :input_source_config, :output_source_config, :resolution_techniques, :created_at, :updated_at, :incremental_run_config, :role_arn, :tags) SENSITIVE = [] include Aws::Structure end |
#role_arn ⇒ String
The Amazon Resource Name (ARN) of the IAM role. Entity Resolution assumes this role to access Amazon Web Services resources on your behalf.
1231 1232 1233 1234 1235 1236 1237 1238 1239 1240 1241 1242 1243 1244 1245 |
# File 'lib/aws-sdk-entityresolution/types.rb', line 1231 class GetMatchingWorkflowOutput < Struct.new( :workflow_name, :workflow_arn, :description, :input_source_config, :output_source_config, :resolution_techniques, :created_at, :updated_at, :incremental_run_config, :role_arn, :tags) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Hash<String,String>
The tags used to organize, track, or control access for this resource.
1231 1232 1233 1234 1235 1236 1237 1238 1239 1240 1241 1242 1243 1244 1245 |
# File 'lib/aws-sdk-entityresolution/types.rb', line 1231 class GetMatchingWorkflowOutput < Struct.new( :workflow_name, :workflow_arn, :description, :input_source_config, :output_source_config, :resolution_techniques, :created_at, :updated_at, :incremental_run_config, :role_arn, :tags) SENSITIVE = [] include Aws::Structure end |
#updated_at ⇒ Time
The timestamp of when the workflow was last updated.
1231 1232 1233 1234 1235 1236 1237 1238 1239 1240 1241 1242 1243 1244 1245 |
# File 'lib/aws-sdk-entityresolution/types.rb', line 1231 class GetMatchingWorkflowOutput < Struct.new( :workflow_name, :workflow_arn, :description, :input_source_config, :output_source_config, :resolution_techniques, :created_at, :updated_at, :incremental_run_config, :role_arn, :tags) SENSITIVE = [] include Aws::Structure end |
#workflow_arn ⇒ String
The ARN (Amazon Resource Name) that Entity Resolution generated for the MatchingWorkflow.
1231 1232 1233 1234 1235 1236 1237 1238 1239 1240 1241 1242 1243 1244 1245 |
# File 'lib/aws-sdk-entityresolution/types.rb', line 1231 class GetMatchingWorkflowOutput < Struct.new( :workflow_name, :workflow_arn, :description, :input_source_config, :output_source_config, :resolution_techniques, :created_at, :updated_at, :incremental_run_config, :role_arn, :tags) SENSITIVE = [] include Aws::Structure end |
#workflow_name ⇒ String
The name of the workflow.
1231 1232 1233 1234 1235 1236 1237 1238 1239 1240 1241 1242 1243 1244 1245 |
# File 'lib/aws-sdk-entityresolution/types.rb', line 1231 class GetMatchingWorkflowOutput < Struct.new( :workflow_name, :workflow_arn, :description, :input_source_config, :output_source_config, :resolution_techniques, :created_at, :updated_at, :incremental_run_config, :role_arn, :tags) SENSITIVE = [] include Aws::Structure end |