Class: Aws::EntityResolution::Types::OutputSource
- Inherits:
-
Struct
- Object
- Struct
- Aws::EntityResolution::Types::OutputSource
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-entityresolution/types.rb
Overview
A list of ‘OutputAttribute` objects, each of which have the fields `Name` and `Hashed`. Each of these objects selects a column to be included in the output table, and whether the values of the column should be hashed.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#apply_normalization ⇒ Boolean
Normalizes the attributes defined in the schema in the input data.
-
#customer_profiles_integration_config ⇒ Types::CustomerProfilesIntegrationConfig
Specifies the Customer Profiles integration configuration for sending matched output directly to Customer Profiles.
-
#kms_arn ⇒ String
Customer KMS ARN for encryption at rest.
-
#output ⇒ Array<Types::OutputAttribute>
A list of ‘OutputAttribute` objects, each of which have the fields `Name` and `Hashed`.
-
#output_s3_path ⇒ String
The S3 path to which Entity Resolution will write the output table.
Instance Attribute Details
#apply_normalization ⇒ Boolean
Normalizes the attributes defined in the schema in the input data. For example, if an attribute has an ‘AttributeType` of `PHONE_NUMBER`, and the data in the input table is in a format of 1234567890, Entity Resolution will normalize this field in the output to (123)-456-7890.
2619 2620 2621 2622 2623 2624 2625 2626 2627 |
# File 'lib/aws-sdk-entityresolution/types.rb', line 2619 class OutputSource < Struct.new( :kms_arn, :output_s3_path, :output, :apply_normalization, :customer_profiles_integration_config) SENSITIVE = [] include Aws::Structure end |
#customer_profiles_integration_config ⇒ Types::CustomerProfilesIntegrationConfig
Specifies the Customer Profiles integration configuration for sending matched output directly to Customer Profiles. When configured, Entity Resolution automatically creates and updates customer profiles based on match clusters, eliminating the need for manual Amazon S3 integration setup.
2619 2620 2621 2622 2623 2624 2625 2626 2627 |
# File 'lib/aws-sdk-entityresolution/types.rb', line 2619 class OutputSource < Struct.new( :kms_arn, :output_s3_path, :output, :apply_normalization, :customer_profiles_integration_config) SENSITIVE = [] include Aws::Structure end |
#kms_arn ⇒ String
Customer KMS ARN for encryption at rest. If not provided, system will use an Entity Resolution managed KMS key.
2619 2620 2621 2622 2623 2624 2625 2626 2627 |
# File 'lib/aws-sdk-entityresolution/types.rb', line 2619 class OutputSource < Struct.new( :kms_arn, :output_s3_path, :output, :apply_normalization, :customer_profiles_integration_config) SENSITIVE = [] include Aws::Structure end |
#output ⇒ Array<Types::OutputAttribute>
A list of ‘OutputAttribute` objects, each of which have the fields `Name` and `Hashed`. Each of these objects selects a column to be included in the output table, and whether the values of the column should be hashed.
2619 2620 2621 2622 2623 2624 2625 2626 2627 |
# File 'lib/aws-sdk-entityresolution/types.rb', line 2619 class OutputSource < Struct.new( :kms_arn, :output_s3_path, :output, :apply_normalization, :customer_profiles_integration_config) SENSITIVE = [] include Aws::Structure end |
#output_s3_path ⇒ String
The S3 path to which Entity Resolution will write the output table.
2619 2620 2621 2622 2623 2624 2625 2626 2627 |
# File 'lib/aws-sdk-entityresolution/types.rb', line 2619 class OutputSource < Struct.new( :kms_arn, :output_s3_path, :output, :apply_normalization, :customer_profiles_integration_config) SENSITIVE = [] include Aws::Structure end |