Class: Aws::EntityResolution::Types::ResolutionTechniques
- Inherits:
-
Struct
- Object
- Struct
- Aws::EntityResolution::Types::ResolutionTechniques
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-entityresolution/types.rb
Overview
An object which defines the ‘resolutionType` and the `ruleBasedProperties`.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#provider_properties ⇒ Types::ProviderProperties
The properties of the provider service.
-
#resolution_type ⇒ String
The type of matching workflow to create.
-
#rule_based_properties ⇒ Types::RuleBasedProperties
An object which defines the list of matching rules to run and has a field ‘rules`, which is a list of rule objects.
-
#rule_condition_properties ⇒ Types::RuleConditionProperties
An object containing the ‘rules` for a matching workflow.
Instance Attribute Details
#provider_properties ⇒ Types::ProviderProperties
The properties of the provider service.
2953 2954 2955 2956 2957 2958 2959 2960 |
# File 'lib/aws-sdk-entityresolution/types.rb', line 2953 class ResolutionTechniques < Struct.new( :resolution_type, :rule_based_properties, :rule_condition_properties, :provider_properties) SENSITIVE = [] include Aws::Structure end |
#resolution_type ⇒ String
The type of matching workflow to create. Specify one of the following types:
-
‘RULE_MATCHING`: Match records using configurable rule-based criteria
-
‘ML_MATCHING`: Match records using machine learning models
-
‘PROVIDER`: Match records using a third-party matching provider
2953 2954 2955 2956 2957 2958 2959 2960 |
# File 'lib/aws-sdk-entityresolution/types.rb', line 2953 class ResolutionTechniques < Struct.new( :resolution_type, :rule_based_properties, :rule_condition_properties, :provider_properties) SENSITIVE = [] include Aws::Structure end |
#rule_based_properties ⇒ Types::RuleBasedProperties
An object which defines the list of matching rules to run and has a field ‘rules`, which is a list of rule objects.
2953 2954 2955 2956 2957 2958 2959 2960 |
# File 'lib/aws-sdk-entityresolution/types.rb', line 2953 class ResolutionTechniques < Struct.new( :resolution_type, :rule_based_properties, :rule_condition_properties, :provider_properties) SENSITIVE = [] include Aws::Structure end |
#rule_condition_properties ⇒ Types::RuleConditionProperties
An object containing the ‘rules` for a matching workflow.
2953 2954 2955 2956 2957 2958 2959 2960 |
# File 'lib/aws-sdk-entityresolution/types.rb', line 2953 class ResolutionTechniques < Struct.new( :resolution_type, :rule_based_properties, :rule_condition_properties, :provider_properties) SENSITIVE = [] include Aws::Structure end |