Class: Aws::EntityResolution::Types::RuleConditionProperties

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-entityresolution/types.rb

Overview

The properties of a rule condition that provides the ability to use more complex syntax.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#matching_configTypes::MatchingConfig

An object that contains configuration settings for the matching process.



3090
3091
3092
3093
3094
3095
# File 'lib/aws-sdk-entityresolution/types.rb', line 3090

class RuleConditionProperties < Struct.new(
  :rules,
  :matching_config)
  SENSITIVE = []
  include Aws::Structure
end

#rulesArray<Types::RuleCondition>

A list of rule objects, each of which have fields ‘ruleName` and `condition`.

Returns:



3090
3091
3092
3093
3094
3095
# File 'lib/aws-sdk-entityresolution/types.rb', line 3090

class RuleConditionProperties < Struct.new(
  :rules,
  :matching_config)
  SENSITIVE = []
  include Aws::Structure
end