Class: Aws::EntityResolution::Types::RuleConditionProperties
- Inherits:
-
Struct
- Object
- Struct
- Aws::EntityResolution::Types::RuleConditionProperties
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-entityresolution/types.rb
Overview
The properties of a rule condition that provides the ability to use more complex syntax.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#matching_config ⇒ Types::MatchingConfig
An object that contains configuration settings for the matching process.
-
#rules ⇒ Array<Types::RuleCondition>
A list of rule objects, each of which have fields ‘ruleName` and `condition`.
Instance Attribute Details
#matching_config ⇒ Types::MatchingConfig
An object that contains configuration settings for the matching process.
3090 3091 3092 3093 3094 3095 |
# File 'lib/aws-sdk-entityresolution/types.rb', line 3090 class RuleConditionProperties < Struct.new( :rules, :matching_config) SENSITIVE = [] include Aws::Structure end |
#rules ⇒ Array<Types::RuleCondition>
A list of rule objects, each of which have fields ‘ruleName` and `condition`.
3090 3091 3092 3093 3094 3095 |
# File 'lib/aws-sdk-entityresolution/types.rb', line 3090 class RuleConditionProperties < Struct.new( :rules, :matching_config) SENSITIVE = [] include Aws::Structure end |