Class: Aws::EntityResolution::Types::StartIdMappingJobInput
- Inherits:
-
Struct
- Object
- Struct
- Aws::EntityResolution::Types::StartIdMappingJobInput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-entityresolution/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#job_type ⇒ String
The job type for the ID mapping job.
-
#output_source_config ⇒ Array<Types::IdMappingJobOutputSource>
A list of ‘OutputSource` objects.
-
#workflow_name ⇒ String
The name of the ID mapping job to be retrieved.
Instance Attribute Details
#job_type ⇒ String
The job type for the ID mapping job.
If the ‘jobType` value is set to `INCREMENTAL`, only new or changed data is processed since the last job run. This is the default value if the `CreateIdMappingWorkflow` API is configured with an `incrementalRunConfig`.
If the ‘jobType` value is set to `BATCH`, all data is processed from the input source, regardless of previous job runs. This is the default value if the `CreateIdMappingWorkflow` API isn’t configured with an ‘incrementalRunConfig`.
If the ‘jobType` value is set to `DELETE_ONLY`, only deletion requests from `BatchDeleteUniqueIds` are processed.
3253 3254 3255 3256 3257 3258 3259 |
# File 'lib/aws-sdk-entityresolution/types.rb', line 3253 class StartIdMappingJobInput < Struct.new( :workflow_name, :output_source_config, :job_type) SENSITIVE = [] include Aws::Structure end |
#output_source_config ⇒ Array<Types::IdMappingJobOutputSource>
A list of ‘OutputSource` objects.
3253 3254 3255 3256 3257 3258 3259 |
# File 'lib/aws-sdk-entityresolution/types.rb', line 3253 class StartIdMappingJobInput < Struct.new( :workflow_name, :output_source_config, :job_type) SENSITIVE = [] include Aws::Structure end |
#workflow_name ⇒ String
The name of the ID mapping job to be retrieved.
3253 3254 3255 3256 3257 3258 3259 |
# File 'lib/aws-sdk-entityresolution/types.rb', line 3253 class StartIdMappingJobInput < Struct.new( :workflow_name, :output_source_config, :job_type) SENSITIVE = [] include Aws::Structure end |