Class: Aws::EntityResolution::Types::UpdateIdMappingWorkflowOutput
- Inherits:
-
Struct
- Object
- Struct
- Aws::EntityResolution::Types::UpdateIdMappingWorkflowOutput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-entityresolution/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#description ⇒ String
A description of the workflow.
-
#id_mapping_techniques ⇒ Types::IdMappingTechniques
An object which defines the ID mapping technique and any additional configurations.
-
#incremental_run_config ⇒ Types::IdMappingIncrementalRunConfig
The incremental run configuration for the update ID mapping workflow output.
-
#input_source_config ⇒ Array<Types::IdMappingWorkflowInputSource>
A list of ‘InputSource` objects, which have the fields `InputSourceARN` and `SchemaName`.
-
#output_source_config ⇒ Array<Types::IdMappingWorkflowOutputSource>
A list of ‘OutputSource` objects, each of which contains fields `outputS3Path` and `KMSArn`.
-
#role_arn ⇒ String
The Amazon Resource Name (ARN) of the IAM role.
-
#workflow_arn ⇒ String
The Amazon Resource Name (ARN) of the workflow role.
-
#workflow_name ⇒ String
The name of the workflow.
Instance Attribute Details
#description ⇒ String
A description of the workflow.
3465 3466 3467 3468 3469 3470 3471 3472 3473 3474 3475 3476 |
# File 'lib/aws-sdk-entityresolution/types.rb', line 3465 class UpdateIdMappingWorkflowOutput < Struct.new( :workflow_name, :workflow_arn, :description, :input_source_config, :output_source_config, :id_mapping_techniques, :incremental_run_config, :role_arn) SENSITIVE = [] include Aws::Structure end |
#id_mapping_techniques ⇒ Types::IdMappingTechniques
An object which defines the ID mapping technique and any additional configurations.
3465 3466 3467 3468 3469 3470 3471 3472 3473 3474 3475 3476 |
# File 'lib/aws-sdk-entityresolution/types.rb', line 3465 class UpdateIdMappingWorkflowOutput < Struct.new( :workflow_name, :workflow_arn, :description, :input_source_config, :output_source_config, :id_mapping_techniques, :incremental_run_config, :role_arn) SENSITIVE = [] include Aws::Structure end |
#incremental_run_config ⇒ Types::IdMappingIncrementalRunConfig
The incremental run configuration for the update ID mapping workflow output.
3465 3466 3467 3468 3469 3470 3471 3472 3473 3474 3475 3476 |
# File 'lib/aws-sdk-entityresolution/types.rb', line 3465 class UpdateIdMappingWorkflowOutput < Struct.new( :workflow_name, :workflow_arn, :description, :input_source_config, :output_source_config, :id_mapping_techniques, :incremental_run_config, :role_arn) SENSITIVE = [] include Aws::Structure end |
#input_source_config ⇒ Array<Types::IdMappingWorkflowInputSource>
A list of ‘InputSource` objects, which have the fields `InputSourceARN` and `SchemaName`.
3465 3466 3467 3468 3469 3470 3471 3472 3473 3474 3475 3476 |
# File 'lib/aws-sdk-entityresolution/types.rb', line 3465 class UpdateIdMappingWorkflowOutput < Struct.new( :workflow_name, :workflow_arn, :description, :input_source_config, :output_source_config, :id_mapping_techniques, :incremental_run_config, :role_arn) SENSITIVE = [] include Aws::Structure end |
#output_source_config ⇒ Array<Types::IdMappingWorkflowOutputSource>
A list of ‘OutputSource` objects, each of which contains fields `outputS3Path` and `KMSArn`.
3465 3466 3467 3468 3469 3470 3471 3472 3473 3474 3475 3476 |
# File 'lib/aws-sdk-entityresolution/types.rb', line 3465 class UpdateIdMappingWorkflowOutput < Struct.new( :workflow_name, :workflow_arn, :description, :input_source_config, :output_source_config, :id_mapping_techniques, :incremental_run_config, :role_arn) SENSITIVE = [] include Aws::Structure end |
#role_arn ⇒ String
The Amazon Resource Name (ARN) of the IAM role. Entity Resolution assumes this role to access Amazon Web Services resources on your behalf.
3465 3466 3467 3468 3469 3470 3471 3472 3473 3474 3475 3476 |
# File 'lib/aws-sdk-entityresolution/types.rb', line 3465 class UpdateIdMappingWorkflowOutput < Struct.new( :workflow_name, :workflow_arn, :description, :input_source_config, :output_source_config, :id_mapping_techniques, :incremental_run_config, :role_arn) SENSITIVE = [] include Aws::Structure end |
#workflow_arn ⇒ String
The Amazon Resource Name (ARN) of the workflow role. Entity Resolution assumes this role to access Amazon Web Services resources on your behalf.
3465 3466 3467 3468 3469 3470 3471 3472 3473 3474 3475 3476 |
# File 'lib/aws-sdk-entityresolution/types.rb', line 3465 class UpdateIdMappingWorkflowOutput < Struct.new( :workflow_name, :workflow_arn, :description, :input_source_config, :output_source_config, :id_mapping_techniques, :incremental_run_config, :role_arn) SENSITIVE = [] include Aws::Structure end |
#workflow_name ⇒ String
The name of the workflow.
3465 3466 3467 3468 3469 3470 3471 3472 3473 3474 3475 3476 |
# File 'lib/aws-sdk-entityresolution/types.rb', line 3465 class UpdateIdMappingWorkflowOutput < Struct.new( :workflow_name, :workflow_arn, :description, :input_source_config, :output_source_config, :id_mapping_techniques, :incremental_run_config, :role_arn) SENSITIVE = [] include Aws::Structure end |