Class: Aws::EntityResolution::Types::UpdateIdMappingWorkflowOutput
- Inherits:
-
Struct
- Object
- Struct
- Aws::EntityResolution::Types::UpdateIdMappingWorkflowOutput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-entityresolution/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#description ⇒ String
A description of the workflow.
-
#id_mapping_techniques ⇒ Types::IdMappingTechniques
An object which defines the ID mapping technique and any additional configurations.
-
#incremental_run_config ⇒ Types::IdMappingIncrementalRunConfig
The incremental run configuration for the update ID mapping workflow output.
-
#input_source_config ⇒ Array<Types::IdMappingWorkflowInputSource>
A list of
InputSourceobjects, which have the fieldsInputSourceARNandSchemaName. -
#output_source_config ⇒ Array<Types::IdMappingWorkflowOutputSource>
A list of
OutputSourceobjects, each of which contains fieldsoutputS3PathandKMSArn. -
#role_arn ⇒ String
The Amazon Resource Name (ARN) of the IAM role.
-
#workflow_arn ⇒ String
The Amazon Resource Name (ARN) of the workflow role.
-
#workflow_name ⇒ String
The name of the workflow.
Instance Attribute Details
#description ⇒ String
A description of the workflow.
3442 3443 3444 3445 3446 3447 3448 3449 3450 3451 3452 3453 |
# File 'lib/aws-sdk-entityresolution/types.rb', line 3442 class UpdateIdMappingWorkflowOutput < Struct.new( :workflow_name, :workflow_arn, :description, :input_source_config, :output_source_config, :id_mapping_techniques, :incremental_run_config, :role_arn) SENSITIVE = [] include Aws::Structure end |
#id_mapping_techniques ⇒ Types::IdMappingTechniques
An object which defines the ID mapping technique and any additional configurations.
3442 3443 3444 3445 3446 3447 3448 3449 3450 3451 3452 3453 |
# File 'lib/aws-sdk-entityresolution/types.rb', line 3442 class UpdateIdMappingWorkflowOutput < Struct.new( :workflow_name, :workflow_arn, :description, :input_source_config, :output_source_config, :id_mapping_techniques, :incremental_run_config, :role_arn) SENSITIVE = [] include Aws::Structure end |
#incremental_run_config ⇒ Types::IdMappingIncrementalRunConfig
The incremental run configuration for the update ID mapping workflow output.
3442 3443 3444 3445 3446 3447 3448 3449 3450 3451 3452 3453 |
# File 'lib/aws-sdk-entityresolution/types.rb', line 3442 class UpdateIdMappingWorkflowOutput < Struct.new( :workflow_name, :workflow_arn, :description, :input_source_config, :output_source_config, :id_mapping_techniques, :incremental_run_config, :role_arn) SENSITIVE = [] include Aws::Structure end |
#input_source_config ⇒ Array<Types::IdMappingWorkflowInputSource>
A list of InputSource objects, which have the fields InputSourceARN and SchemaName.
3442 3443 3444 3445 3446 3447 3448 3449 3450 3451 3452 3453 |
# File 'lib/aws-sdk-entityresolution/types.rb', line 3442 class UpdateIdMappingWorkflowOutput < Struct.new( :workflow_name, :workflow_arn, :description, :input_source_config, :output_source_config, :id_mapping_techniques, :incremental_run_config, :role_arn) SENSITIVE = [] include Aws::Structure end |
#output_source_config ⇒ Array<Types::IdMappingWorkflowOutputSource>
A list of OutputSource objects, each of which contains fields outputS3Path and KMSArn.
3442 3443 3444 3445 3446 3447 3448 3449 3450 3451 3452 3453 |
# File 'lib/aws-sdk-entityresolution/types.rb', line 3442 class UpdateIdMappingWorkflowOutput < Struct.new( :workflow_name, :workflow_arn, :description, :input_source_config, :output_source_config, :id_mapping_techniques, :incremental_run_config, :role_arn) SENSITIVE = [] include Aws::Structure end |
#role_arn ⇒ String
The Amazon Resource Name (ARN) of the IAM role. Entity Resolution assumes this role to access Amazon Web Services resources on your behalf.
3442 3443 3444 3445 3446 3447 3448 3449 3450 3451 3452 3453 |
# File 'lib/aws-sdk-entityresolution/types.rb', line 3442 class UpdateIdMappingWorkflowOutput < Struct.new( :workflow_name, :workflow_arn, :description, :input_source_config, :output_source_config, :id_mapping_techniques, :incremental_run_config, :role_arn) SENSITIVE = [] include Aws::Structure end |
#workflow_arn ⇒ String
The Amazon Resource Name (ARN) of the workflow role. Entity Resolution assumes this role to access Amazon Web Services resources on your behalf.
3442 3443 3444 3445 3446 3447 3448 3449 3450 3451 3452 3453 |
# File 'lib/aws-sdk-entityresolution/types.rb', line 3442 class UpdateIdMappingWorkflowOutput < Struct.new( :workflow_name, :workflow_arn, :description, :input_source_config, :output_source_config, :id_mapping_techniques, :incremental_run_config, :role_arn) SENSITIVE = [] include Aws::Structure end |
#workflow_name ⇒ String
The name of the workflow.
3442 3443 3444 3445 3446 3447 3448 3449 3450 3451 3452 3453 |
# File 'lib/aws-sdk-entityresolution/types.rb', line 3442 class UpdateIdMappingWorkflowOutput < Struct.new( :workflow_name, :workflow_arn, :description, :input_source_config, :output_source_config, :id_mapping_techniques, :incremental_run_config, :role_arn) SENSITIVE = [] include Aws::Structure end |